OC.L10N.register(
    "spreed",
    {
    "a conversation" : "一个对话",
    "(Duration %s)" : "（时长 %s）",
    "You attended a call with {user1}" : "您参加了{user1}的通话",
    "_%n guest_::_%n guests_" : ["%n 位访客"],
    "You attended a call with {user1} and {user2}" : "您参加了{user1}和{user2}的通话",
    "You attended a call with {user1}, {user2} and {user3}" : "您参加了{user1}，{user2}和{user3} 的通话",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "您参加了{user1}，{user2}，{user3}和{user4}的通话",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "您参加了{user1}，{user2}，{user3}，{user4}和{user5}的通话",
    "_%n other_::_%n others_" : ["及另外%n人"],
    "{actor} invited you to {call}" : "{actor}邀请您加入{call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "您被邀请加入一个<strong>对话</strong>或一个<strong>通话</strong>",
    "Other activities" : "其他活动",
    "Talk" : "通话",
    "Guest" : "访客",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## 欢迎来到 Nextcloud 通话！\n此对话将向您介绍Nextcloud通话中的新功能",
    "## New in Talk %s" : "## Talk %s 的新功能",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge和Safari浏览器现可用于参与音视频通话",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- 一对一的对话现在是持久性的，并且不会意外地变成群组对话。另外，当其中一个参与者离开对话时，对话不会被自动删除。只有当双方都离开时，对话才会从服务器上删除",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- 您可以在聊天中输入 \"@all\" 以通知所有参与者",
    "- With the \"arrow-up\" key you can repost your last message" : "- 您可以使用 \"向上\" 键重复输入您的上一条消息",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- 通话应用现在可以支持命令了，将 \"/help\" 作为聊天消息发出以查看您的管理员是否配置了一些命令",
    "- With projects you can create quick links between conversations, files and other items" : "- 您可以使用项目来在对话、文件和其他项目间创建快速链接",
    "- You can now mention guests in the chat" : "－您现在可以在聊天中提及访客",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- 对话现在可以设置一个大厅。 这将使主持人可以加入聊天并开始通话以准备会议，而用户和访客则必须等待",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- 您现在可以直接回复消息，为其他用户提供更多关于您的消息的上下文",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- 现在，搜索对话和参与者也将过滤您现有的对话，使查找以前的对话更加容易",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- 现在，您可以在安装圈子应用后将自定义用户组添加到对话中",
    "- Check out the new grid and call view" : "- 体验一下新的排列和通话界面",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- 您现在可以从您的设备上传或拖拽文件到一场对话",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- 分享文件现在可以直接从聊天界面使用查看应用打开",
    "- You can now search for chats and messages in the unified search in the top bar" : "- 你现在可以在顶栏的统一搜索框搜索聊天和消息",
    "- Spice up your messages with emojis from the emoji picker" : "- 用从表情选择器挑选来的表情符号为您的消息加点料",
    "- You can now change your camera and microphone while being in a call" : "- 您现在可以在通话时切换您的摄像头和麦克风",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- 给你的对话提供一些背景和描述，并打开它，以便登录用户可以找到它并加入他们自己",
    "- See a read status and send failed messages again" : "- 查看阅读状态，并再次发送失败的消息",
    "- Raise your hand in a call with the R key" : "- 在通话中按 R 键举手",
    "- Join the same conversation and call from multiple devices" : "- 加入同一对话并从多个设备进行呼叫",
    "- Send voice messages, share your location or contact details" : "- 发送语音消息，分享您的位置或联系方式",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- 在对话中加入群组，群组成员会自动被添加为参与者",
    "- A preview of your audio and video is shown before joining a call" : "- 加入通话前会显示音视频预览",
    "- You can now blur your background in the newly designed call view" : "- 你现在可以在新设计的通话视图中模糊你的背景",
    "- Moderators can now assign general and individual permissions to participants" : "- 主持人现在可以为参与者分配一般和单独权限",
    "- You can now react to chat messages" : "- 您现在可以对聊天消息做出回应",
    "- In the sidebar you can now find an overview of the latest shared items" : "- 现在您可以在侧边栏中找到最近已分享项目的概况",
    "- Use a poll to collect the opinions of others or settle on a date" : "- 使用投票搜集他人意见或确定日期",
    "- Configure an expiration time for chat messages" : "- 配置聊天消息的过期时间",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- 在不通知他人的情況下开始通话。通话开始后，您可以发送单独的通话通知。",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- 在不紧急的情況下发送聊天消息而不通知收讯人",
    "- Emojis can now be autocompleted by typing a \":\"" : "- 现在可以通过输入“:”来自动补全表情符号",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- 通过输入“/”来使用新的智能选择器链接各种项目",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- 主持人现在可以创建分组讨论室（需要高性能后端）",
    "- Calls can now be recorded (requires the High-performance backend)" : "- 现在可以录制通话（需要高性能后端）",
    "- Conversations can now have an avatar or emoji as icon" : "- 对话现在可以使用头像或者表情符号来作为图标",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- 视频通话除了模糊背景外，现在也可以使用虚拟背景了",
    "- Reactions are now available during calls" : "- 现在可以在通话期间做出回应",
    "- Typing indicators show which users are currently typing a message" : "- 输入指示器显示目前正在输入的用户",
    "- Groups can now be mentioned in chats" : "- 现在可以在聊天中提及群组",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- 如果注册了转录提供者应用，会自动转录通话录制",
    "- Chat messages can be translated if a translation provider app is registered" : "- 如果注册了提供翻译的应用程序，则可以翻译聊天消息",
    "- **Markdown** can now be used in _chat_ messages" : "- _聊天信息_ 中可以使用 **Markdown** 了",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- 支持使用 Webhook 接入机器人。详情请参考文档 https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- 为聊天消息设置稍后提醒",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- 使用 **自我备注** 对话在您的设备之间做笔记和共享信息",
    "- Captions allow to send a message with a file at the same time" : "- 字幕允许同时发送消息和文件",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- 现在在共享屏幕时可以看到演讲者的视频，并且通话反应以动画形式显示",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- 登录的作者和主持人现在可以在 6 小时内编辑消息",
    "- Unsent message drafts are now saved in your browser" : "- 未发送的消息草稿现在会保存在浏览器中",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- 现在可以与其他 Talk 服务器以联合方式进行文本聊天",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- 主持人现在可以封禁账号和访客，以防止他们重新加入对话",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- 对话中现在会显示来自链接日历活动和外出接替者的预定的通话",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- 现在可以与其他 Talk 服务器以联合方式进行通话（需要高性能后端）",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- 引入适用于 Windows、macOS 和 Linux 的 Nextcloud Talk 桌面客户端：%s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- 使用 Nextcloud 助手总结通话记录和聊天中的未读消息",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- 改进了会议功能，通过电子邮件地址识别受邀访客、导入参与者列表、起草投票和下载通话参与者列表",
    "- Archive conversations to stay focused" : "- 将对话存档以保持专注",
    "- Schedule a meeting into your calendar from within a conversation" : "- 从对话中将会议安排到您的日历中",
    "- Search for messages of the current conversation directly in the right sidebar" : "- 直接在右侧边栏中搜索当前对话的消息",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- 使用新的紧凑列表（在通话设置中启用）一眼就能看到更多对话",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- 会议对话现在可以同步日历中的标题和描述，并使用搜索过滤器隐藏，直到接近开始时才显示",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- 在通知设置中将对话标记为敏感，以在对话列表和通知中隐藏消息内容",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- 要在“勿扰”期间接收推送通知，请将对话标记为重要",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- 将其他参与者添加到一对一通话中，以便即时创建新的群组通话",
    "- Use threads to keep your chat and discussions organized" : "- 使用帖子来组织您的聊天和讨论",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- 通话期间现在可以进行实时转录（需要实时转录外部应用和高性能后端）",
    "- Moderators can now pin messages so they are kept at the top" : "- 主持人现在可以置顶消息，使其始终在顶部显示",
    "- Schedule a message to send it at a later time" : "- 安排消息以便稍后发送",
    "_All %n participant_::_All %n participants_" : ["全部 %n 位参与者"],
    "Talk updates ✅" : "通话应用更新 ✅",
    "Reaction deleted by author" : "回应被作者删除",
    "{actor} created the conversation" : "{actor}创建了对话",
    "You created the conversation" : "您创建了对话",
    "System created the conversation" : "系统创建了对话",
    "An administrator created the conversation" : "管理员创建了这个对话",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor}将对话“%1$s”重命名为了“%2$s”",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "您将对话 \"%1$s\" 重命名为 \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "一位管理员将对话从“%1$s”重命名为“%2$s”",
    "{actor} set the description" : "{actor} 设置了描述",
    "You set the description" : "你设置了描述",
    "An administrator set the description" : "一名管理员设置了描述",
    "{actor} removed the description" : "{actor} 移除了描述",
    "You removed the description" : "您移除了描述",
    "An administrator removed the description" : "一位管理员移除了描述",
    "You started a silent call" : "您发起了一个静默通话",
    "Outgoing silent call" : "静默去电",
    "{actor} started a silent call" : "{actor} 发起了一个静默通话",
    "Incoming silent call" : "静默来电",
    "You started a call" : "您开始了一个通话",
    "Outgoing call" : "去电",
    "{actor} started a call" : "{actor} 开始了一个通话",
    "Incoming call" : "来电",
    "{actor} joined the call" : "{actor} 加入了通话",
    "You joined the call" : "您加入了通话",
    "{actor} left the call" : "{actor} 离开了通话",
    "You left the call" : "您离开了通话",
    "{actor} unlocked the conversation" : "{actor}解锁了对话",
    "You unlocked the conversation" : "您解锁了对话",
    "An administrator unlocked the conversation" : "一位管理员解锁了对话",
    "{actor} locked the conversation" : "{actor}锁定了对话",
    "You locked the conversation" : "您锁定了对话",
    "An administrator locked the conversation" : "一位管理员锁定了对话",
    "{actor} limited the conversation to the current participants" : "{actor}将对话限于当前参与者",
    "You limited the conversation to the current participants" : "你将对话限制在当前参与者范围内",
    "An administrator limited the conversation to the current participants" : "管理员将对话限于当前参与者",
    "{actor} opened the conversation to registered users" : "{actor} 向注册用户开放了对话",
    "You opened the conversation to registered users" : "你向注册用户开放了对话",
    "An administrator opened the conversation to registered users" : "管理员向注册用户开放了对话",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} 向已注册用户和通过访客应用创建的账号开放了此对话",
    "You opened the conversation to registered users and users created with the Guests app" : "你向已注册用户和通过访客应用创建的账号开放了此对话",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "管理员向已注册用户和通过访客应用创建的账号开放了此对话",
    "The conversation is now open to everyone" : "此对话现在对所有人开放",
    "{actor} opened the conversation to everyone" : "{actor}将对话开放给所有人",
    "You opened the conversation to everyone" : "您将对话开放给所有人",
    "{actor} restricted the conversation to moderators" : "{actor}将对话限制到与主持人之间",
    "You restricted the conversation to moderators" : "你将对话限制到与主持人之间",
    "{actor} started breakout rooms" : "{actor}开始了分组讨论室",
    "You started breakout rooms" : "您开始了分组讨论室",
    "{actor} stopped breakout rooms" : "{actor}停止了分组讨论室",
    "You stopped breakout rooms" : "您停止了分组讨论室",
    "{actor} allowed guests" : "{actor} 允许了访客加入",
    "You allowed guests" : "您允许了访客加入",
    "An administrator allowed guests" : "一位管理员允许了访客",
    "{actor} disallowed guests" : "{actor} 禁止了访客加入",
    "You disallowed guests" : "您禁止了访客加入",
    "An administrator disallowed guests" : "一位管理员禁止了访客",
    "{actor} set a password" : "{actor} 设置了一个密码",
    "You set a password" : "您设置了一个密码",
    "An administrator set a password" : "一位管理员设置了口令",
    "{actor} removed the password" : "{actor} 移除了密码",
    "You removed the password" : "您移除了密码",
    "An administrator removed the password" : "一位管理员移除了口令",
    "{actor} added {user}" : "{actor} 添加了 {user}",
    "You joined the conversation" : "您加入了对话",
    "{actor} joined the conversation" : "{actor}加入了对话",
    "You added {user}" : "您添加了 {user}",
    "{actor} added you" : "{actor} 添加了您",
    "An administrator added you" : "一位管理员添加了您",
    "An administrator added {user}" : "一位管理员添加了 {user}",
    "You left the conversation" : "您离开了对话",
    "{actor} left the conversation" : "{actor}离开了对话",
    "{actor} removed {user}" : "{actor} 移除了 {user}",
    "You removed {user}" : "您移除了 {user}",
    "{actor} removed you" : "{actor} 移除了您",
    "An administrator removed you" : "一位管理员移除了您",
    "An administrator removed {user}" : "一位管理员移除了 {user}",
    "{actor} invited {federated_user}" : "{actor} 邀请了 {federated_user}",
    "You invited {federated_user}" : "你邀请了 {federated_user}",
    "You accepted the invitation" : "您接收了邀请",
    "{actor} invited you" : "{actor} 邀请了您",
    "An administrator invited you" : "管理员邀请了您",
    "An administrator invited {federated_user}" : "管理员邀请了 {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} 接受了邀请",
    "{actor} removed {federated_user}" : "{actor} 移除了{federated_user}",
    "You removed {federated_user}" : "您移除了 {federated_user}",
    "You declined the invitation" : "您拒绝了邀请",
    "An administrator removed {federated_user}" : "管理员移除了 {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} 拒绝了邀請",
    "{actor} added group {group}" : "{actor} 添加了小组 {group}",
    "You added group {group}" : "你添加了小组 {group}",
    "An administrator added group {group}" : "一名管理员添加了小组 {group}",
    "{actor} removed group {group}" : "{actor} 删除了小组 {group}",
    "You removed group {group}" : "你删除了小组 {group}",
    "An administrator removed group {group}" : "一名管理员删除了小组 {group}",
    "{actor} added team {circle}" : "{actor} 添加了团队 {circle}",
    "You added team {circle}" : "您添加了团队 {circle}",
    "An administrator added team {circle}" : "管理员添加了团队 {circle}",
    "{actor} removed team {circle}" : "{actor} 移除了团队 {circle}",
    "You removed team {circle}" : "您移除了团队 {circle}",
    "An administrator removed team {circle}" : "管理员移除了团队 {circle}",
    "{actor} added {phone}" : "{actor} 添加了 {phone}",
    "You added {phone}" : "你添加了 {phone}",
    "An administrator added {phone}" : "管理员添加了 {phone}",
    "{actor} removed {phone}" : "{actor} 移除了 {phone}",
    "You removed {phone}" : "你移除了 {phone}",
    "An administrator removed {phone}" : "管理员移除了 {phone}",
    "{actor} promoted {user} to moderator" : "{actor}将{user}提升为主持人",
    "You promoted {user} to moderator" : "您将{user}提升为主持人",
    "{actor} promoted you to moderator" : "{actor}提升您为主持人",
    "An administrator promoted you to moderator" : "一位管理员将您提升为主持人",
    "An administrator promoted {user} to moderator" : "一位管理员将{user}提升为主持人",
    "{actor} demoted {user} from moderator" : "{actor}将{user}撤销主持人",
    "You demoted {user} from moderator" : "您将{user}撤销主持人",
    "{actor} demoted you from moderator" : "{actor}将您撤销主持人",
    "An administrator demoted you from moderator" : "一位管理员将您撤销主持人",
    "An administrator demoted {user} from moderator" : "一位管理员将{user}撤销主持人",
    "{actor} shared a file which is no longer available" : "{actor}分享了一个不再可用的文件",
    "You shared a file which is no longer available" : "您分享了一个不再可用的文件",
    "File shares are currently not supported in federated conversations" : "联合对话现在不支持文件分享",
    "The shared location is malformed" : "分享的位置变形",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} 设置了 Matterbridge，使此对话与其他聊天同步",
    "You set up Matterbridge to synchronize this conversation with other chats" : "你设置了 Matterbridge，以将此对话与其他聊天同步",
    "{actor} created thread {title}" : "{actor} 创建了帖子 {title}",
    "You created thread {title}" : "您创建了帖子 {title}",
    "{actor} renamed thread {title}" : "{actor} 已将帖子重命名为 {title}",
    "You renamed thread {title}" : "您已将帖子重命名为 {title}",
    "{actor} updated the Matterbridge configuration" : "{actor} 更新了 Matterbridge 配置",
    "You updated the Matterbridge configuration" : "你更新了 Matterbridge 配置",
    "{actor} removed the Matterbridge configuration" : "{actor} 移除了 Matterbridge 配置",
    "You removed the Matterbridge configuration" : "你移除了 Matterbridge 配置",
    "{actor} started Matterbridge" : "{actor} 启动了 Matterbridge",
    "You started Matterbridge" : "你启动了 Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} 停止了 Matterbridge",
    "You stopped Matterbridge" : "你停止了 Matterbridge",
    "{actor} deleted a message" : "{actor}删除了一条消息",
    "You deleted a message" : "你删除了一条消息",
    "{actor} edited a message" : "{actor} 编辑了一条信息",
    "You edited a message" : "您编辑了一条信息",
    "{actor} pinned a message" : "{actor} 置顶了一条消息",
    "You pinned a message" : "您置顶了一条消息",
    "{actor} unpinned a message" : "{actor} 取消置顶了一条消息",
    "Message was automatically unpinned" : "消息已自动取消置顶",
    "You unpinned a message" : "您取消置顶了一条消息",
    "{actor} deleted a reaction" : "{actor} 刪除了一个回应",
    "You deleted a reaction" : "你删除了一个回应",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["您将消息过期时间设置为%n星期"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["您将消息过期时间设置为%n天"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["您将消息过期时间设置为%n小时"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["您将消息过期时间设置为%n分钟"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor}将消息过期时间设置为%n星期"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor}将消息过期时间设置为%n天"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor}将消息过期时间设置为%n小时"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor}将消息过期时间设置为%n分钟"],
    "{actor} disabled message expiration" : "{actor}禁用了消息过期时间",
    "You disabled message expiration" : "您禁用了消息过期时间",
    "{actor} cleared the history of the conversation" : "{actor}清除了对话历史",
    "You cleared the history of the conversation" : "你清除了对话历史",
    "{actor} set the conversation picture" : "{actor}设置了对话图片",
    "You set the conversation picture" : "您设置了对话图片",
    "{actor} removed the conversation picture" : "{actor}移除了对话图片",
    "You removed the conversation picture" : "您设置了对话图片",
    "{actor} ended the poll {poll}" : "{actor} 结束了投票 {poll}",
    "You ended the poll {poll}" : "您结束了投票 {poll}",
    "{actor} started the video recording" : "{actor}开始视频录制",
    "You started the video recording" : "您开始视频录制",
    "{actor} stopped the video recording" : "{actor}停止视频录制",
    "You stopped the video recording" : "您停止视频录制",
    "{actor} started the audio recording" : "{actor}开始音频录制",
    "You started the audio recording" : "您开始音频录制",
    "{actor} stopped the audio recording" : "{actor}停止音频录制",
    "You stopped the audio recording" : "您停止音频录制",
    "The recording failed" : "录制失败",
    "Someone voted on the poll {poll}" : "有人在投票 {poll} 中投票了",
    "Message deleted by author" : "消息被作者删除了",
    "Message deleted by {actor}" : "消息被 {actor} 删除了",
    "Message deleted by you" : "消息被你删除了",
    "Deleted user" : "删除用户",
    "Unknown number" : "未知号码",
    "Administration" : "管理员",
    "System" : "系统",
    "%s (guest)" : "%s（访客）",
    "Missed call" : "未接来电",
    "Unanswered call" : "未接通话",
    "Call ended (Duration {duration})" : "通话结束（时长 {duration}）",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "通话结束，因为已达到最大通话时长（时长 {duration}）",
    "{actor} ended the call (Duration {duration})" : "{actor} 结束了通话（时长 {duration}）",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["与 %n 位访客的通话已结束，因为已达到最大通话时长（时长 {duration}）"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["与 %n 位访客的通话已结束（时长 {duration}）"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} 结束了与 %n 位访客的通话（时长 {duration}）"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "与 {user1} 的通话已结束，因为已达到最大通话时长（时长 {duration}）",
    "Call with {user1} ended (Duration {duration})" : "与 {user1} 的通话已结束（时长 {duration}）",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} 结束了与 {user1} 的通话（时长 {duration}）",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "与 {user1} 和 {user2} 的通话已结束，因为已达到最大通话时长（时长 {duration}）",
    "Call with {user1} and {user2} ended (Duration {duration})" : "与 {user1} 和 {user2} 的通话已结束（时长 {duration}）",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} 结束了与 {user1} 和 {user2} 的通话（时长 {duration}）",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "与 {user1}、{user2} 和 {user3} 的通话已结束，因为已达到最大通话时长（时长 {duration}）",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "与 {user1}、{user2} 和 {user3} 的通话已结束（时长 {duration}）",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} 结束了与 {user1}、{user2} 和 {user3} 的通话（时长 {duration}）",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "与 {user1}、{user2}、{user3} 和 {user4} 的通话已结束，因为已达到最大通话时长（时长 {duration}）",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "与 {user1}、{user2}、{user3} 和 {user4} 的通话已结束（时长 {duration}）",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} 结束了与 {user1}、{user2} 、 {user3} 和 {user4} 的通话（时长 {duration}）",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "与 {user1}、{user2}、{user3}、{user4} 和 {user5} 的通话已结束，因为已达到最大通话时长（时长 {duration}）",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "与 {user1}、{user2}、{user3}、{user4} 和 {user5} 的通话已结束（时长 {duration}）",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} 结束了与 {user1}、{user2} 、 {user3}、{user4} 和 {user5} 的通话（时长 {duration}）",
    "Message of {user} in {conversation}" : "{conversation} 中来自 {user} 的消息",
    "Message of {user}" : "{user} 的消息",
    "Message of a deleted user in {conversation}" : "{conversation} 中已删除用户的消息",
    "Talk conversations" : "对话",
    "Talk to %s" : "和 %s 对话",
    "An error occurred. Please contact your administrator." : "发生了一个错误。请联系你的管理员。",
    "App disabled" : "应用已禁用",
    "Conversation subfolders are disabled" : "对话子文件夹已禁用",
    "Storage quota exceeded" : "超出存储限额",
    "Could not prepare conversation folder" : "无法准备对话文件夹",
    "File not found" : "文件未找到",
    "Path must point to a file" : "路径必须指向文件",
    "File is not inside the conversation draft folder for this room" : "文件不在此聊天室的对话草稿文件夹中",
    "File is not shared, or shared but not with the user" : "文件未分享，或没有分享给用户",
    "No account available to delete." : "没有可删除的账号。",
    "Poll" : "投票",
    "Password needs to be set" : "需要设置密码",
    "Uploading the file failed" : "上传文件失败",
    "No image file provided" : "未提供图片文件",
    "File is too big" : "文件太大",
    "Invalid file provided" : "提供了无效文件",
    "Invalid image" : "无效图片",
    "Unknown filetype" : "未知的文件类型",
    "Talk mentions" : "通话提及",
    "More conversations" : "更多对话",
    "Say hi to your friends and colleagues!" : "跟您的朋友和同事打个招呼！",
    "No unread mentions" : "无未读的提及",
    "Call in progress" : "通话中...",
    "You were mentioned" : "有人提及了您",
    "Write to conversation" : "向对话写入",
    "Writes event information into a conversation of your choice" : "将活动信息写入您选择的对话",
    "Missing email field in header line" : "标题行中缺少电子邮件字段",
    "Following lines are invalid: %s" : "以下行无效：%s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s 邀请您加入对话“%2$s”。",
    "You were invited to conversation \"%s\"." : "您已受邀加入对话“%s”。",
    "Conversation invitation" : "对话邀请",
    "Scheduled time" : "预定时间",
    "Description" : "描述",
    "You can also dial-in via phone with the following details" : "你也可以通过电话拨号，详情如下 ",
    "Dial-in information" : "拨号信息",
    "Meeting ID" : "会议ID",
    "Your PIN" : "您的 PIN 码",
    "Click the button below to join the lobby now." : "点击下方按钮立即加入大厅。",
    "Click the link below to join the lobby now." : "点击下方链接立即加入大厅。",
    "Join lobby for \"%s\"" : "加入“%s”的大厅",
    "Click the button below to join the conversation now." : "点击下方按钮立即加入对话。",
    "Click the link below to join the conversation now." : "点击下方链接立即加入对话。",
    "Join \"%s\"" : "加入“%s”",
    "Meeting" : "会议",
    "Password request: %s" : "密码请求: %s",
    "Private conversation" : "私有对话",
    "Deleted user (%s)" : "已删除用户（%s）",
    "Failed to upload call recording" : "上传通话录制失败",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "录制服务器上传通话{call}的录制失败。请联系管理员。",
    "Share to chat" : "分享至聊天",
    "Dismiss notification" : "忽略通知",
    "Call recording now available" : "通话录制现在可用",
    "The recording for the call in {call} was uploaded to {file}." : "{call}中的通话录制已上传到{file}。",
    "Transcript now available" : "转录现在可用",
    "The transcript for the call in {call} was uploaded to {file}." : "{call} 通话的转录已上传至 {file}。",
    "Failed to transcript call recording" : "无法转录通话录制",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "服务器无法转录 {call} 中 {file} 的通话录音。请联系管理员。",
    "Call summary now available" : "通话摘要现已可用",
    "The summary for the call in {call} was uploaded to {file}." : "{call} 中的通话摘要已上传到 {file}。",
    "Failed to summarize call recording" : "无法总结通话记录",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "服务器无法总结 {call} 中的通话在 {file} 上的录音。请联系管理员。 ",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} 邀请您加入 {remoteServer} 上的 {roomName}",
    "Accept" : "接受",
    "Decline" : "拒绝",
    "{user1} invited you to a federated conversation" : "{user1} 邀请您加入联合对话",
    "Someone reacted" : "有人做出了回应",
    "New message" : "新消息",
    "Reminder" : "提醒",
    "Someone mentioned you" : "有人提及您",
    "Notification" : "通知",
    "Someone reacted in a private conversation" : "有人在私人对话中做出了回应",
    "You received a message in a private conversation" : "您在私人对话中收到了一条消息",
    "Reminder in a private conversation" : "私人对话中的提醒",
    "Someone mentioned you in a private conversation" : "有人在私人对话中提及你",
    "Notification in a private conversation" : "私人对话中的通知",
    "Reminder: You in {call}" : "提醒：你在 {call} 中",
    "Reminder: {user} in {call}" : "提醒： {user} 在 {call} 中",
    "Reminder: Deleted user in {call}" : "提醒：已删除的用户在 {call} 中",
    "Reminder: {guest} (guest) in {call}" : "提醒：访客 {guest} 在 {call} 中",
    "Reminder: Guest in {call}" : "提醒：访客在 {call} 中",
    "{user} reacted with {reaction}" : "{user} 表示了 {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} 在 {call} 中表示了 {reaction}",
    "Deleted user reacted with {reaction} in {call}" : "已删除的用户在 {call} 中表示了 {reaction}",
    "{guest} (guest) reacted with {reaction} in {call}" : "访客 {guest} 在 {call} 中表示了 {reaction}",
    "Guest reacted with {reaction} in {call}" : "访客在 {call} 中表示了 {reaction}",
    "{user} in {call}" : "{call} 中的 {user}",
    "Deleted user in {call}" : "删除了 {call} 中的用户",
    "{guest} (guest) in {call}" : "{guest} （访客） 位于 {call}",
    "Guest in {call}" : "在 {call} 中的访客",
    "{user} sent you a private message" : "{user}给您发了一条私信",
    "{user} sent a message in conversation {call}" : "{user}在对话{call}中发了一条消息",
    "A deleted user sent a message in conversation {call}" : "一位已删除的用户在对话{call}中发了一条消息",
    "{guest} (guest) sent a message in conversation {call}" : "{guest}（访客）在对话{call}中发了一条消息",
    "A guest sent a message in conversation {call}" : "一位访客在对话{call}中发了一条消息",
    "{user} replied to your private message" : "{user}回复了您的私信",
    "{user} replied to your message in conversation {call}" : "{user}在对话{call}中回复了您的消息",
    "A deleted user replied to your message in conversation {call}" : "一个已删除的用户在对话{call}中回复了您的消息",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest}（访客）在对话{call}中回复了您的消息",
    "A guest replied to your message in conversation {call}" : "一个访客在对话{call}中回复了您的消息",
    "Reminder: You in private conversation {call}" : "提醒：你在私密对话 {call} 中",
    "Reminder: A deleted user in private conversation {call}" : "提醒：已删除的用户在私密对话 {call} 中",
    "Reminder: {user} in private conversation" : "提醒：{user} 在私密对话中",
    "Reminder: You in conversation {call}" : "提醒：你在对话 {call} 中",
    "Reminder: {user} in conversation {call}" : "提醒：{user} 在对话 {call} 中",
    "Reminder: A deleted user in conversation {call}" : "提醒：已删除的用户在对话 {call} 中",
    "Reminder: {guest} (guest) in conversation {call}" : "提醒：访客 {guest} 在对话 {call} 中",
    "Reminder: A guest in conversation {call}" : "提醒：访客在对话 {call} 中",
    "{user} reacted with {reaction} to your private message" : "{user}对您的私信做出了{reaction}回应",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user}在对话{call}中对您的消息做出了{reaction}回应",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "一位已删除的用户在对话{call}中对您的消息做出了{reaction}回应",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest}（访客）在对话{call}中对您的消息做出了{reaction}回应",
    "A guest reacted with {reaction} to your message in conversation {call}" : "访客在对话{call}中对您的消息做出了{reaction}回应",
    "{user} mentioned you in a private conversation" : "{user} 在一个私人对话中提及了您",
    "{user} mentioned group {group} in conversation {call}" : "{user}在对话{call}中提及了群组{group}",
    "{user} mentioned team {team} in conversation {call}" : "{user} 在对话 {call} 中提及了团队 {team}",
    "{user} mentioned everyone in conversation {call}" : "{user}在对话{call}中提及了所有人",
    "{user} mentioned you in conversation {call}" : "{user} 在对话 {call} 中提及了您",
    "A deleted user mentioned group {group} in conversation {call}" : "一位已删除的用户在对话 {call} 中提及了群组 {group}",
    "A deleted user mentioned team {team} in conversation {call}" : "一位已删除的用户在对话 {call} 中提及了团队 {team}",
    "A deleted user mentioned everyone in conversation {call}" : "一位已删除的用户在对话 {call} 中提及了所有人",
    "A deleted user mentioned you in conversation {call}" : "一位已删除的用户在对话 {call} 中提及了您",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest}（访客）在对话 {call} 中提及了群组 {group}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest}（访客）在对话 {call} 中提及了团队 {team}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest}（访客）在对话 {call} 中提及了所有人",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest}（访客）在对话 {call} 中提及了您 ",
    "A guest mentioned group {group} in conversation {call}" : "一位访客在对话 {call} 中提及了群组 {group}",
    "A guest mentioned team {team} in conversation {call}" : "一位访客在对话 {call} 中提及了团队 {team}",
    "A guest mentioned everyone in conversation {call}" : "一位访客在对话 {call} 中提及了所有人",
    "A guest mentioned you in conversation {call}" : "一位访客在对话 {call} 中提及了您 ",
    "View message" : "查看消息",
    "Dismiss reminder" : "取消提醒",
    "View chat" : "查看聊天",
    "{user} invited you to a group conversation: {call}" : "{user}邀请您加入一个小组对话：{call}",
    "Join call" : "加入通话",
    "Answer call" : "接听通话",
    "{user} would like to talk with you" : "{user}想和您对话",
    "Call back" : "回拨",
    "You missed a call from {user}" : "您错过了来自 {user} 的一个通话",
    "Accept call" : "接听通话",
    "Incoming phone call from {call}" : "来自 {call} 的来电",
    "You missed a phone call from {call}" : "您错过了来自 {call} 的通话",
    "A group call has started in {call}" : "已在 {call} 小组中开始通话",
    "You missed a group call in {call}" : "您在 {call} 中错过了一个组通话",
    "{email} is requesting the password to access {file}" : "{email} 请求密码以访问 {file}",
    "{email} tried to request the password to access {file}" : "{email} 尝试请求密码访问 {file}",
    "Someone is requesting the password to access {file}" : "有人请求密码以访问 {file}",
    "Someone tried to request the password to access {file}" : "有人试图要求密码访问 {file}",
    "Open settings" : "打开设置",
    "Hosted signaling server added" : "已添加托管的信令服务器",
    "The hosted signaling server is now configured and will be used." : "托管的信令服务器现已配置并将被使用。",
    "Hosted signaling server removed" : "已移除托管的信令服务器",
    "The hosted signaling server was removed and will not be used anymore." : "托管的信令服务器已被移除且无法再使用。",
    "Hosted signaling server changed" : "已更改托管的信令服务器",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "托管信令服务器账号的状态已从 \"{oldstatus}\" 变更为 \"{newstatus}\"",
    "pending" : "等待中",
    "active" : "活动",
    "expired" : "已过期",
    "blocked" : "已封锁",
    "error" : "错误",
    "The certificate of {host} expires in {days} days" : "{host}的证书将在{days}天后过期",
    "The certificate of {host} expired" : "{host}的证书已过期",
    "Contact via Talk" : "通过通话应用联系",
    "Open Talk" : "打开通话应用",
    "Default" : "默认",
    "Send messages, create threads, and start voice and video calls." : "发送消息、创建线程以及开始语音和视频通话。",
    "Presentation" : "演示文稿",
    "Voice room" : "语音室",
    "Directly join the call, ideal for catch-ups or spontaneous meetings." : "直接加入通话，非常适合即时会议或自发会议。",
    "Webinar" : "网络研讨会",
    "Conversations" : "对话",
    "Messages in current conversation" : "当前对话中的消息",
    "{user}" : "{user}",
    "Messages" : "消息",
    "{user} in {conversation}" : "{conversation} 中的 {user}",
    "Messages in other conversations" : "在其他对话中的消息",
    "One-to-one rooms always need to show the other users avatar" : "一对一的聊天室一律需要显示其他用户的邮箱",
    "Invalid emoji character" : "无效的表情符号字符",
    "Invalid background color" : "无效的背景颜色",
    "Avatar image is not square" : "头像图像不是正方形",
    "Room {number}" : "聊天室{number}",
    "Other" : "其他",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "因测试服务器不可达，无法请求测试。请稍后重试。",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "此实例的身份验证存在一个问题。也许不能从外部访问它来验证它的 URL。",
    "Something unexpected happened." : "出现了一些异常情况。",
    "The URL is invalid." : "URL 无效",
    "An HTTPS URL is required." : "要求使用 HTTPS 链接",
    "The email address is invalid." : "电子邮件地址无效",
    "The language is invalid." : "语言无效",
    "The country is invalid." : "国家/地区无效",
    "There is a problem with the request of the trial. Please check your logs for further information." : "试用请求有个问题。请检查你的日志以获得进一步的信息。",
    "Too many requests are send from your servers address. Please try again later." : "你的服务器地址发送了太多的请求。请稍后再试。",
    "There is already a trial registered for this Nextcloud instance." : "此Nextcloud实例已有一个已注册的trial。",
    "Something unexpected happened. Please try again later." : "出现了一些异常情况。请稍后重试。",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "因测试服务器行为异常，无法请求测试。请稍后重试。",
    "Trial requested but failed to get account information. Please check back later." : "已请求测试但无法获取账号信息。请稍后检查。",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "此请求的验证操作有问题。可能是因为无法从外部访问来验证它的URL。",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "由于测试服务器行为错误，无法获取帐户信息。请稍后再来查看。 ",
    "There is a problem with fetching the account information. Please check your logs for further information." : "获取账号信息有问题。请查看您的日志以获取更多信息。",
    "There is no such account registered." : "没有这个已注册账号。",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "因测试服务器不可达，无法获取账号信息。请稍后检查。",
    "Deleting the hosted signaling server account failed. Please check back later." : "删除托管信令服务器失败。请稍后检查。",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "因测试服务器行为异常，无法删除账号。请稍后检查。",
    "There is a problem with deleting the account. Please check your logs for further information." : "删除账号有问题。请查看您的日志以获取更多信息。",
    "Too many requests are sent from your servers address. Please try again later." : "你的服务器地址发送了太多的请求。请稍后再试。 ",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "因测试服务器不可达，无法删除账号。请稍后检查。",
    "Note to self" : "自我备注",
    "A place for your private notes, thoughts and ideas" : "一个用于记录您的私人笔记、思考和想法的地方",
    "Transcript is AI generated and may contain mistakes" : "转录是 AI 生成的，可能包含错误",
    "Summary is AI generated and may contain mistakes" : "摘要是 AI 生成的，可能包含错误",
    "Let's get started!" : "让我们开始吧！",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** 是安全的、自托管的通信平台，与 Nextcloud 生态系统无缝集成。\n\n#### Nextcloud Talk 的主要特点：\n\n* 私聊和群聊中的聊天和消息\n* 语音和视频通话\n* 文件分享和与其他 Nextcloud 应用的集成\n* 可定制的对话设置、审核和隐私控制\n* 网页、桌面和移动设备（iOS 和 Android）\n* 私密且安全的通信\n\n在[用户文档](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)中了解详情。",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# 欢迎使用 Nextcloud Talk\n\nNextcloud Talk 是与 Nextcloud 集成的私密且功能强大的消息应用。在私人或群组对话中聊天，通过语音和视频通话进行协作，组织网络研讨会和活动，定制您的对话等。",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 设置文本格式以创建丰富的消息\n\n在 Nextcloud Talk 中，您可以使用 Markdown 语法来格式化您的消息。例如，应用 **加粗** 或 *倾斜* 格式，或 `将文本突出显示为代码`。您甚至可以创建表格，并在文本中添加标题。\n\n需要修正拼写错误或更改格式吗？通过点击消息菜单中的“编辑消息”来编辑您的消息。",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 添加附件和链接\n\n使用“+”按钮从 Nextcloud Hub 附加文件。分享文件和各种 Nextcloud 应用中的项目。一些应用甚至支持互动式微件，例如文本应用。",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 让对话流畅：提及用户、回应消息等等\n\n您可以使用 %s 提及对话中的所有人，或者输入“@”并从列表中选择特定参与者的名称来提及他们。",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "您可以回复消息，将其转发给其他聊天和联系人，或复制消息内容。",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ 使用智能选择器执行更多操作\n\n只需输入“/”或转到“+”菜单即可打开智能选择器，您可以在其中将各种内容附加到您的消息中。您可以配置智能选择器，使其能够从 Nextcloud 应用、GIF、地图位置、AI 生成的内容等添加项目。",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ 管理对话设置\n\n在对话菜单中，您可以访问各种设置来管理对话，例如：\n* 编辑对话信息\n* 管理通知\n* 应用众多审核规则\n* 配置访问权限和安全性\n* 启用机器人\n* 以及更多！",
    "Andorra" : "安道尔",
    "United Arab Emirates" : "阿拉伯联合酋长国",
    "Afghanistan" : "阿富汗",
    "Antigua and Barbuda" : "安提瓜和巴布达",
    "Anguilla" : "安圭拉",
    "Albania" : "阿尔巴尼亚",
    "Armenia" : "亚美尼亚共和国",
    "Angola" : "安哥拉",
    "Antarctica" : "南极洲",
    "Argentina" : "阿根廷",
    "American Samoa" : "美属萨摩亚",
    "Austria" : "奥地利",
    "Australia" : "澳大利亚",
    "Aruba" : "阿鲁巴",
    "Åland Islands" : "奥兰",
    "Azerbaijan" : "阿塞拜疆",
    "Bosnia and Herzegovina" : "波斯尼亚和黑塞哥维那",
    "Barbados" : "巴巴多斯",
    "Bangladesh" : "孟加拉国",
    "Belgium" : "比利时",
    "Burkina Faso" : "布基纳法索",
    "Bulgaria" : "保加利亚",
    "Bahrain" : "巴林",
    "Burundi" : "布隆迪",
    "Benin" : "贝宁",
    "Saint Barthélemy" : "圣巴泰勒米",
    "Bermuda" : "百慕大",
    "Brunei Darussalam" : "文莱达鲁萨兰国",
    "Bolivia, Plurinational State of" : "多民族玻利维亚国",
    "Bonaire, Sint Eustatius and Saba" : "博内尔岛，圣尤斯特歇斯岛和萨巴岛",
    "Brazil" : "巴西",
    "Bahamas" : "巴哈马",
    "Bhutan" : "不丹",
    "Bouvet Island" : "布维岛",
    "Botswana" : "博茨瓦纳",
    "Belarus" : "白俄罗斯",
    "Belize" : "伯利兹",
    "Canada" : "加拿大",
    "Cocos (Keeling) Islands" : "科科斯（基林）群岛",
    "Congo, the Democratic Republic of the" : "刚果民主共和国",
    "Central African Republic" : "中非共和国",
    "Congo" : "刚果",
    "Switzerland" : "瑞士",
    "Côte d'Ivoire" : "科特迪瓦",
    "Cook Islands" : "库克群岛",
    "Chile" : "智利",
    "Cameroon" : "喀麦隆",
    "China" : "中国",
    "Colombia" : "哥伦比亚",
    "Costa Rica" : "哥斯达黎加",
    "Cuba" : "古巴",
    "Cabo Verde" : "佛得角",
    "Curaçao" : "库拉索",
    "Christmas Island" : "圣诞岛",
    "Cyprus" : "赛浦路斯",
    "Czechia" : "捷克",
    "Germany" : "德国",
    "Djibouti" : "吉布提",
    "Denmark" : "丹麦",
    "Dominica" : "多米尼加",
    "Dominican Republic" : "多明尼加共和国",
    "Algeria" : "阿尔及利亚",
    "Ecuador" : "厄瓜多尔",
    "Estonia" : "爱沙尼亚",
    "Egypt" : "埃及",
    "Western Sahara" : "西撒哈拉",
    "Eritrea" : "厄立特里亚",
    "Spain" : "西班牙",
    "Ethiopia" : "埃塞俄比亚",
    "Finland" : "芬兰",
    "Fiji" : "斐济",
    "Falkland Islands (Malvinas)" : "福克兰群岛（马尔维纳斯群岛）",
    "Micronesia, Federated States of" : "密克罗尼西亚联邦",
    "Faroe Islands" : "法罗群岛",
    "France" : "法国",
    "Gabon" : "加蓬",
    "United Kingdom of Great Britain and Northern Ireland" : "大不列颠及北爱尔兰联合王国",
    "Grenada" : "格林纳达",
    "Georgia" : "格鲁吉亚",
    "French Guiana" : "法属圭亚那",
    "Guernsey" : "根西岛",
    "Ghana" : "加纳",
    "Gibraltar" : "直布罗陀",
    "Greenland" : "格陵兰",
    "Gambia" : "冈比亚",
    "Guinea" : "几内亚",
    "Guadeloupe" : "瓜德罗普岛",
    "Equatorial Guinea" : "赤道几内亚",
    "Greece" : "希腊",
    "South Georgia and the South Sandwich Islands" : "南乔治亚岛和南桑威奇群岛",
    "Guatemala" : "危地马拉",
    "Guam" : "关岛",
    "Guinea-Bissau" : "几内亚-比绍",
    "Guyana" : "圭亚那",
    "Hong Kong" : "香港",
    "Heard Island and McDonald Islands" : "赫德岛和麦当劳群岛",
    "Honduras" : "洪都拉斯",
    "Croatia" : "克罗地亚",
    "Haiti" : "海地",
    "Hungary" : "匈牙利",
    "Indonesia" : "印度尼西亚",
    "Ireland" : "爱尔兰",
    "Israel" : "以色列",
    "Isle of Man" : "马恩岛",
    "India" : "印度",
    "British Indian Ocean Territory" : "英属印度洋领地",
    "Iraq" : "伊拉克",
    "Iran, Islamic Republic of" : "伊朗伊斯兰共和国",
    "Iceland" : "冰岛",
    "Italy" : "意大利",
    "Jersey" : "泽西",
    "Jamaica" : "牙买加",
    "Jordan" : "约旦",
    "Japan" : "日本",
    "Kenya" : "肯尼亚",
    "Kyrgyzstan" : "吉尔吉斯斯坦",
    "Cambodia" : "柬埔寨",
    "Kiribati" : "基里巴斯",
    "Comoros" : "科摩罗",
    "Saint Kitts and Nevis" : "圣基茨和尼维斯",
    "Korea, Democratic People's Republic of" : "朝鲜民主主义人民共和国",
    "Korea, Republic of" : "韩国（共和国）",
    "Kuwait" : "科威特",
    "Cayman Islands" : "开曼群岛",
    "Kazakhstan" : "哈萨克斯坦",
    "Lao People's Democratic Republic" : "老挝",
    "Lebanon" : "黎巴嫩",
    "Saint Lucia" : "圣卢西亚",
    "Liechtenstein" : "列支敦士登",
    "Sri Lanka" : "斯里兰卡",
    "Liberia" : "利比里亚",
    "Lesotho" : "莱索托",
    "Lithuania" : "立陶宛",
    "Luxembourg" : "卢森堡",
    "Latvia" : "拉脱维亚",
    "Libya" : "利比亚",
    "Morocco" : "摩洛哥",
    "Monaco" : "摩纳哥",
    "Moldova, Republic of" : "摩尔多瓦（共和国）",
    "Montenegro" : "黑山",
    "Saint Martin (French part)" : "圣马丁（法国部分）",
    "Madagascar" : "马达加斯加",
    "Marshall Islands" : "马绍尔群岛",
    "North Macedonia" : "北马其顿",
    "Mali" : "马里",
    "Myanmar" : "缅甸",
    "Mongolia" : "蒙古",
    "Macao" : "澳门",
    "Northern Mariana Islands" : "北马里亚纳群岛",
    "Martinique" : "马提尼克",
    "Mauritania" : "毛里塔尼亚",
    "Montserrat" : "蒙特塞拉特",
    "Malta" : "马耳他",
    "Mauritius" : "毛里求斯",
    "Maldives" : "马尔代夫",
    "Malawi" : "马拉维",
    "Mexico" : "墨西哥",
    "Malaysia" : "马来西亚",
    "Mozambique" : "莫桑比克",
    "Namibia" : "纳米比亚",
    "New Caledonia" : "新喀里多尼亚",
    "Niger" : "尼日尔",
    "Norfolk Island" : "诺福克岛",
    "Nigeria" : "尼日利亚",
    "Nicaragua" : "尼加拉瓜",
    "Netherlands" : "荷兰",
    "Norway" : "挪威",
    "Nepal" : "尼泊尔",
    "Nauru" : "瑙鲁",
    "Niue" : "纽埃",
    "New Zealand" : "新西兰",
    "Oman" : "阿曼",
    "Panama" : "巴拿马",
    "Peru" : "秘鲁",
    "French Polynesia" : "法属波利尼西亚",
    "Papua New Guinea" : "巴布亚新几内亚",
    "Philippines" : "菲律宾",
    "Pakistan" : "巴基斯坦",
    "Poland" : "波兰",
    "Saint Pierre and Miquelon" : "圣皮埃尔和密克隆",
    "Pitcairn" : "皮特凯恩",
    "Puerto Rico" : "波多黎各",
    "Palestine, State of" : "巴勒斯坦",
    "Portugal" : "葡萄牙",
    "Palau" : "帕劳",
    "Paraguay" : "巴拉圭",
    "Qatar" : "卡塔尔",
    "Réunion" : "留尼汪",
    "Romania" : "罗马尼亚",
    "Serbia" : "塞尔维亚",
    "Russian Federation" : "俄罗斯联邦",
    "Rwanda" : "卢旺达",
    "Saudi Arabia" : "沙特阿拉伯",
    "Solomon Islands" : "所罗门群岛",
    "Seychelles" : "塞舌尔",
    "Sudan" : "苏丹",
    "Sweden" : "瑞典",
    "Singapore" : "新加坡",
    "Saint Helena, Ascension and Tristan da Cunha" : "圣赫勒拿，阿森松岛和特里斯坦达库尼亚",
    "Slovenia" : "斯洛文尼亚",
    "Svalbard and Jan Mayen" : "斯瓦尔巴和扬马延",
    "Slovakia" : "斯洛伐克",
    "Sierra Leone" : "塞拉利昂",
    "San Marino" : "圣马力诺",
    "Senegal" : "塞内加尔",
    "Somalia" : "索马里",
    "Suriname" : "苏里南",
    "South Sudan" : "南苏丹",
    "Sao Tome and Principe" : "圣多美和普林西比",
    "El Salvador" : "萨尔瓦多",
    "Sint Maarten (Dutch part)" : "圣马丁（荷兰部分）",
    "Syrian Arab Republic" : "阿拉伯叙利亚共和国",
    "Eswatini" : "斯威士兰",
    "Turks and Caicos Islands" : "特克斯和凯科斯群岛",
    "Chad" : "乍得",
    "French Southern Territories" : "法国南部领地",
    "Togo" : "多哥",
    "Thailand" : "泰国",
    "Tajikistan" : "塔吉克斯坦",
    "Tokelau" : "托克劳",
    "Timor-Leste" : "东帝汶",
    "Turkmenistan" : "土库曼斯坦",
    "Tunisia" : "突尼斯",
    "Tonga" : "汤加",
    "Turkey" : "土耳其",
    "Trinidad and Tobago" : "特立尼达和多巴哥",
    "Tuvalu" : "图瓦卢",
    "Taiwan, Province of China" : "台湾",
    "Tanzania, United Republic of" : "坦桑尼亚联合共和国",
    "Ukraine" : "乌克兰",
    "Uganda" : "乌干达",
    "United States Minor Outlying Islands" : "美国本土外小岛屿",
    "United States of America" : "美利坚合众国",
    "Uruguay" : "乌拉圭",
    "Uzbekistan" : "乌兹别克斯坦",
    "Holy See" : "教廷",
    "Saint Vincent and the Grenadines" : "圣文森特和格林纳丁斯",
    "Venezuela, Bolivarian Republic of" : "委内瑞拉玻利瓦尔共和国",
    "Virgin Islands, British" : "英属维尔京群岛",
    "Virgin Islands, U.S." : "美属维尔京群岛",
    "Viet Nam" : "越南",
    "Vanuatu" : "瓦努阿图",
    "Wallis and Futuna" : "瓦利斯和富图纳群岛",
    "Samoa" : "萨摩亚",
    "Yemen" : "也门",
    "Mayotte" : "马约特",
    "South Africa" : "南非",
    "Zambia" : "赞比亚",
    "Zimbabwe" : "津巴布韦",
    "Background blur" : "背景模糊",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "无法检查 WASM 加载支持。请手动检查您的 Web 服务器是否提供 `.wasm` 文件。",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "您的 Web 服务器设置不正确，无法传递 `.wasm` 文件。这通常是 Nginx 配置的问题。对于背景模糊，它需要调整以同时传递 `.wasm` 文件。将您的 Nginx 配置与我们文档中推荐的配置进行比较。",
    "Talk configuration values" : "Talk 配置值",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "只有系统 cron 支持强制通话时长。请启用系统 cron 或移除 `max_call_duration` 配置。",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "由于技术限制，较小的 `max_call_duration` 值（当前设置为 %d）不可执行。后台任务仅每 5 分钟执行一次，因此使用风险自负。",
    "Federation" : "联合",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "强烈推荐在启用 Talk 联合后配置“memcache.locking”。",
    "High-performance backend" : "高性能后端  ",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "未配置高性能后端——在没有高性能后端的情况下运行 Nextcloud Talk 仅适用于非常小规模的通话（最多 2-3 位参与者）。请设置高性能后端，以确保多位参与者的通话无缝进行。",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "运行高性能后端“conversation_cluster”模式已被弃用，在即将推出的版本中将不再受支持。如今，高性能后端支持真正的集群，应该使用它。",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "定义多个高性能后端已被弃用，在即将推出的版本中将不再受支持。相反，负载均衡器应该与集群信令服务器一起设置，并在 Talk 设置中配置。",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "所用算法 %1$s 的已存储公钥与已存储的私钥不匹配。运行 %2$s 以修复此问题。",
    "High-performance backend not configured correctly. Run %s for details." : "高性能后端配置不正确。运行 %s 以获取详情。",
    "High-performance backend not configured correctly" : "高性能后端配置不正确",
    "Error: Cannot connect to server" : "错误：无法连接到服务器 ",
    "Error: Server did not respond with proper JSON" : "错误：服务器没有用正确的 JSON 响应",
    "Error: Certificate expired" : "错误：证书已过期",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "错误：Nextcloud 服务器和高性能后端服务器的系统时间不同步。请确保两台服务器都连接到时间服务器或手动同步它们的时间。",
    "Could not get version" : "无法获取版本",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "错误：当前的运行版本为：{version}，服务器需要更新以与此版本的 Talk 兼容",
    "Error: Server responded with: {error}" : "错误：服务器回复：{error}",
    "Error: Unknown error occurred" : "错误：发生未知错误",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "警告：当前的运行版本为：{version}，此版本的 Talk 中的下列功能不受服务器支持：{features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "强烈推荐在使用高性能后端运行 Nextcloud Talk 时配置内存缓存。",
    "Client Push" : "客户端推送",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "客户端推送已安装，这将提高 Talk 通知的及时性。",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "{notify_push} 未安装。这可能会导致 Talk 通知延迟。",
    "Recording backend" : "录制后端",
    "Using the recording backend requires a High-performance backend." : "使用录制后端需要高性能后端。",
    "No recording backend configured" : "未配置录制后端",
    "SIP configuration" : "SIP 配置",
    "Using the SIP functionality requires a High-performance backend." : "使用 SIP 功能需要高性能后端。",
    "Assigned Talk phone numbers must not start with + or 0. Please remove or update the following numbers:\n{list}" : "分配的 Talk 电话号码不得以 + 或 0 开头。请移除或更新以下号码：\n{list}",
    "No SIP backend configured" : "未配置 SIP 后端",
    "Invalid date, date format must be YYYY-MM-DD" : "日期无效，日期格式必须为 YYYY-MM-DD",
    "Conversation not found" : "未找到对话",
    "Path is already shared with this conversation" : "路径已与此对话分享",
    "Chat, video & audio-conferencing using WebRTC" : "使用 WebRTC 进行聊天、视频和音频会议",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "使用 WebRTC 进行聊天、视频和音频会议\n\n* 💬 **聊天** Nextcloud Talk 附带了简单的文本聊天功能，允许您从 Nextcloud 文件应用或本地设备分享或上传文件，并提及其他参与者。\n* 👥 **私人、群组、公开和密码保护的通话！**邀请某人、整个群组或发送公开链接以邀请通话。\n* 🌐 **联合聊天** 与其他 Nextcloud 服务器上的用户聊天\n* 💻 **屏幕共享！** 与通话参与者共享您的屏幕。\n* 🚀 **与其他 Nextcloud 应用集成** 如文件、日历、用户状态、仪表盘、流程、地图、智能选择器、联系人、Deck 等。\n* 🌉 **与其他聊天解决方案同步** 通过将 [Matterbridge](https://github.com/42wim/matterbridge/) 集成到 Talk 中，您可以轻松地将许多其他聊天解决方法同步到 Nextcloud Talk，反之亦然。",
    "Leave call" : "离开通话",
    "Navigating away from the page will leave the call in {conversation}" : "离开此页面也将中断 {conversation} 中的通话",
    "Stay in call" : "保持通话",
    "Error occurred when getting the conversation information" : "获取对话信息时出错",
    "Discuss this file" : "讨论此文件",
    "Share this file with others to discuss it" : "与他人分享此文件以讨论它",
    "Share this file" : "分享此文件",
    "Join conversation" : "加入对话",
    "This conversation is password-protected." : "此对话受密码保护。",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "我们检测到您的IP进行了多次无效密码尝试。因此，您的下一次登录最长会延迟30秒。",
    "The password is wrong. Try again." : "用户名或密码错误！请重试",
    "Password" : "密码",
    "Submit" : "提交",
    "Error requesting the password." : "请求密码错误。",
    "Request password" : "需要密码",
    "This conversation has ended" : "此对话已结束",
    "Error occurred when joining the conversation" : "加入对话时发生错误",
    "Close Talk sidebar" : "关闭通话应用侧边栏",
    "Open Talk sidebar" : "打开通话应用侧边栏",
    "Everyone" : "所有人",
    "Users and moderators" : "用户和主持人",
    "Moderators only" : "仅管理员",
    "Disable calls" : "禁用通话",
    "Save changes" : "保存更改",
    "Saving …" : "正在保存……",
    "Saved!" : "已保存！",
    "Limit to groups" : "限制于分组",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "当至少一个分组被选择时，只有列出分组的成员才能成为对话的一分子。",
    "Guests can still join public conversations." : "访客仍可加入公开对话。",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "已不再能使用通话应用的用户在其以前的对话中仍会被列为参与者，他们的聊天消息也将被保留。",
    "Limit using Talk" : "限制使用通话应用",
    "Limit creating a public and group conversation" : "限制创建公开和群组对话",
    "Limit creating conversations" : "限制创建对话",
    "Limit starting a call" : "限制开始一个通话",
    "Limit starting calls" : "限制开始通话",
    "When a call has started, everyone with access to the conversation can join the call." : "当一个通话已开始时，能访问该对话的所有人都能加入通话",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "此服务器安装了下列机器人。请参阅文档以获取一份现有的{linkstart2}机器人列表{linkend}，或者了解{linkstart1}如何编写您自己的机器人{linkend}。",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "此服务器上未安装任何机器人。请参阅文档以获取一份现有的{linkstart2}机器人列表{linkend}，或者了解{linkstart1}如何编写您自己的机器人{linkend}。",
    "Description is not provided" : "未提供描述",
    "Locked for moderators" : "为主持人锁定",
    "Enabled" : "已启用",
    "Disabled" : "已禁用",
    "Bots settings" : "机器人设置",
    "State" : "状况",
    "Name" : "名称",
    "Last error" : "上次错误",
    "Total errors count" : "总错误数",
    "Find more bots" : "查找更多机器人",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "可以在{linkstart}共享设置页面{linkend}配置受信任的服务器。",
    "Beta" : "Beta",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "联合聊天和通话已经可以工作了。附件处理将在未来的版本中推出。",
    "Enable Federation in Talk app" : "在 Talk 应用中启用联合功能",
    "Permissions" : "权限",
    "Allow users to be invited to federated conversations" : "允许邀请用户加入联合对话",
    "Allow users to invite federated users into conversation" : "允许用户邀请联合用户加入对话",
    "Only allow to federate with trusted servers" : "只允许与受信任的服务器联合",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "当至少选择了一个群组时，只有列出的群组中的用户可以邀请联合用户进行对话。",
    "Groups allowed to invite federated users" : "允许邀请联合用户的群组",
    "Select groups …" : "选择群组…",
    "All messages" : "全部消息",
    "@-mentions only" : "仅被 @ 提及的消息",
    "Off" : "关闭",
    "General settings" : "通用设置",
    "Default notification settings" : "默认通知设置",
    "Default group notification" : "默认分组通知",
    "Default group notification for new groups" : "对新分组的默认分组通知",
    "Integration into other apps" : "与其他应用的集成",
    "Allow conversations on files" : "允许文件上的对话",
    "Allow conversations on public shares for files" : "允许文件的公开分享上的对话",
    "End-to-end encrypted calls" : "端到端加密通话",
    "Enable encryption" : "启用加密",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "使用已配置 SIP 桥接的端到端加密通话需要更新版本的高性能后端和 SIP 桥接。",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "移动客户端目前不支持端到端加密通话。",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "点击上方按钮，表格中的信息将发送到 Struktur AG 的服务器。您可以在 {linkstart}spreed.eu{linkend} 上找到更多信息。",
    "Pending" : "待定",
    "Error" : "错误",
    "Blocked" : "被阻止",
    "Active" : "活动",
    "Expired" : "已过期",
    "Never" : "永不",
    "The trial could not be requested. Please try again later." : "无法请求测试。请稍后重试。",
    "The account could not be deleted. Please try again later." : "账号无法删除。请稍后重试。",
    "Hosted High-performance backend" : "托管的高性能后端",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "我们的合作伙伴 Struktur AG 提供了一种可以请求托管信令服务器的服务。为此，你只需要填写下面的表单，然后Nextcloud就会请求它。一旦为你设置好服务器，凭据将被自动填写。这将覆盖现有的信令服务器设置。",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "如果您的高性能后端账号包括 STUN 和/或 TURN 功能，将会相应更新设置。",
    "URL of this Nextcloud instance" : "此Nextcloud实例的URL",
    "Full name of the user requesting the trial" : "请求试用的用户全名",
    "Email of the user" : "用户的电子邮箱地址 ",
    "Language" : "语言",
    "Country" : "国家/地区",
    "Request signaling server trial" : "请求信令服务器试用",
    "You can see the current status of your hosted signaling server in the following table." : "您可在以下表格中查看您托管的信令服务器的当前状态。",
    "Status" : "状态",
    "Created at" : "创建于",
    "Expires at" : "过期于",
    "Limits" : "限制",
    "STUN included" : "包括 STUN",
    "Yes" : "是",
    "No" : "否",
    "TURN included" : "包括 TURN",
    "Delete the signaling server account" : "删除信令服务器账号",
    "_%n user_::_%n users_" : ["%n 个用户"],
    "Installed version: {version}" : "已安装版本：{version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "您可以安装Matterbridge以将Nextcloud通话应用连接到其他服务，请访问其{linkstart1}GitHub页面{linkend}以获得更多信息。下载并安装应用程序可能需要一段时间。如果超时，请从{linkstart2}Nextcloud应用商店{linkend}手动安装。",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Matterbridge 二进制文件的权限不正确。请确保 Matterbridge 二进制文件由正确的用户拥有并且可以执行。它可以在“/…/nextcloud/apps/talk_matterbridge/bin/”中找到。",
    "Matterbridge binary was not found or couldn't be executed." : "找不到 Matterbridge 二进制文件或无法执行。",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "你也可以通过 config 手动设置 Matterbridge 二进制文件的路径。更多信息请查阅  {linkstart}Matterbridge 集成文档{linkend}",
    "Downloading …" : "下载中 …",
    "Install Talk Matterbridge" : "安装通话应用Matterbridge",
    "An error occurred while installing the Matterbridge app" : "安装Matterbridge应用程序时发生错误",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "安装通话应用Matterbridge时发生错误。请手动安装。",
    "Failed to execute Matterbridge binary." : "执行Matterbridge二进制文件失败。",
    "Matterbridge integration" : "Matterbridge 集成",
    "Enable Matterbridge integration" : "启用 Matterbridge 集成",
    "Status: Checking connection" : "状态：正在检查连接",
    "OK: Running version: {version}" : "OK：运行版本：{version}",
    "Error: Server seems to be a Signaling server" : "错误：服务器似乎是信令服务器",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "错误：Nextcloud 服务器和录制后端服务器的系统时间不同步。请确保两台服务器都连接到时间服务器或手动同步它们的时间。",
    "Recording backend URL" : "录制后端 URL",
    "Validate SSL certificate" : "验证 SSL 证书",
    "Delete this server" : "删除此服务器",
    "Test this server" : "测试此服务器",
    "Disabled for all calls" : "对所有通话禁用",
    "Enabled for all calls" : "对所有通话启用",
    "Configurable on conversation level by moderators" : "由各对话主持人自行设置",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "PHP设置“upload_max_filesize”或“post_max_size”仅允许上传最大{maxUpload}的文件。",
    "Recording backend settings saved" : "已保存录制后端设置",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "允许各对话主持人自行决定是否征求录制授权。所有参与者在加入对话中的所有通话前需要同意录制",
    "The consent to be recorded will be required for each participant before joining every call." : "所有参与者在加入任何通话前都需要同意录制",
    "The consent to be recorded is not required." : "不征求录制授权",
    "Recording backend configuration is only possible with a High-performance backend." : "录制后端配置仅适用于高性能后端。",
    "Add a new recording backend server" : "添加新的录制后端服务器",
    "Shared secret" : "已分享密码",
    "Recording consent" : "录制准许",
    "Recording transcription" : "录制转录",
    "Automatically transcribe call recordings with a transcription provider" : "使用转录提供者自动转录通话录制内容",
    "Automatically summarize call recordings with transcription and summary providers" : "使用转录和摘要提供者自动总结通话录制内容",
    "SIP configuration saved!" : "SIP 配置已保存！",
    "SIP configuration is only possible with a High-performance backend." : "SIP 配置仅适用于高性能后端。",
    "Enable SIP Dial-out option" : "启用 SIP 外呼选项",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "信令服务器需要更新以支持 SIP 外呼功能。",
    "Do not show SIP Dial-out caller number" : "不要显示 SIP 外呼主叫号码",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "匿名号码应向对方显示为“未知号码”或“隐藏号码”",
    "Dial-out number" : "外呼号码",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "外呼电话使用 E164 格式号码作为备用主叫号码",
    "Dial-out prefix" : "外呼前缀",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "外呼电话主叫号码前缀（默认为 `+`）",
    "Restrict SIP configuration" : "限制 SIP 配置",
    "Enable SIP configuration" : "启用 SIP 配置",
    "Only users of the following groups can enable SIP in conversations they moderate" : "只有以下群组的用户可以在自己主持的对话中开启 SIP",
    "Phone number (Country)" : "电话号码（国家/地区）",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "这些信息会在邀请邮件中发送，也会在侧边栏中显示给所有参与者。 ",
    "Nextcloud base URL" : "Nextcloud 基本 URL",
    "Talk Backend URL" : "Talk 后端 URL",
    "WebSocket URL" : "WebSocket URL",
    "Available features" : "可用功能",
    "Error: Websocket connection failed" : "错误：Websocket 连接失败",
    "Error code" : "错误代码",
    "Error message" : "错误消息",
    "Error: Websocket connection failed. Check browser console" : "错误：Websocket 连接失败，请检查浏览器控制台",
    "High-performance backend URL" : "高性能后端 URL",
    "Missing High-performance backend warning hidden" : "缺失高性能后端警告已隐藏",
    "High-performance backend settings saved" : "高性能后端设置已保存",
    "Nextcloud Talk setup not complete" : "Nextcloud Talk 设置未完成",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "请注意，在没有高性能后端的 2 位以上参与者的通话中，参与者很可能会遇到连接问题，并导致参与设备的高负载。",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "安装高性能后端，以确保多位参与者的通话无缝进行。",
    "Nextcloud portal" : "Nextcloud 门户",
    "Quick installation guide" : "快速安装指南",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "有多位参与者的通话和对话需要高性能后端。如果没有后端，所有参与者都必须为其他参与者单独上传自己的视频，这很可能会导致连接问题和参与设备的高负载。",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "强烈推荐在使用具有高性能后端的 Nextcloud Talk 时设置分布式缓存。",
    "Add High-performance backend server" : "添加高性能后端服务器",
    "Warn about connectivity issues in calls with more than 2 participants" : "在超过 2 位参与者的通话中警告连接问题",
    "STUN server URL" : "STUN 服务器 URL",
    "The server address is invalid" : "服务器地址无效",
    "STUN settings saved" : "STUN设置已保存",
    "STUN servers" : "STUN 服务器",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN 服务器用以探测路由器下的参与者的公网 IP 地址。",
    "Add a new STUN server" : "添一个新的STUN服务器",
    "{schema} scheme must be used with a domain" : "{schema} 协议必须与域名一起使用",
    "{option1} and {option2}" : "{option1} 和 {option2}",
    "{option} only" : "仅 {option} ",
    "OK: Successful ICE candidates returned by the TURN server" : "OK：TURN服务器成功返回ICE候选",
    "Error: No working ICE candidates returned by the TURN server" : "错误：TURN服务器没有返回可用的ICE候选",
    "Testing whether the TURN server returns ICE candidates" : "测试TURN服务器是否返回ICE候选",
    "TURN server schemes" : "TURN 服务器 scheme",
    "TURN server URL" : "TURN 服务器URL",
    "TURN server secret" : "TURN 服务器密码",
    "TURN server protocols" : "TURN 服务器协议",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "TURN 服务器服务器用于代理来自防火墙后参与者的通信。如果单个参与者无法连接到其他参与者，则很可能需要一个 TURN 服务器。设置说明见 {linkstart}此文档{linkend}",
    "TURN settings saved" : "TURN设置已保存",
    "TURN servers" : "TURN 服务器",
    "Add a new TURN server" : "添加一个新的TURN服务器",
    "Failed" : "失败了",
    "OK" : "好",
    "Checking …" : "检查中...",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "失败：此浏览器禁用或不支持 WebAssembly。请启用 WebAssembly 或使用支持它的浏览器进行检查。",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "失败：Web服务器没有正确返回”.wasm” 和“.tflite” 文件。请查看通话应用文档中的“系统要求”部分。",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "好：web 服务器正确返回了 \".wasm\" 和 \".tflite\" 文件",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "PHP与Apache配置似乎不兼容。请注意，PHP仅能与MPM_PREFORK模块一起使用，PHP-FPM仅能与MPM_EVENT模块一起使用。",
    "Web server setup checks" : "Web 服务器设置检查",
    "Files required for virtual background can be loaded" : "可以加载背景模糊所需的文件",
    "Federated user" : "联合云用户",
    "Assign participants to rooms" : "指派参与者到聊天室",
    "Configure breakout rooms" : "配置分组讨论室",
    "Number of breakout rooms" : "分组讨论室数量",
    "You can create from 1 to 20 breakout rooms." : "您可以创建 1 到 20 个分组讨论室。",
    "Assignment method" : "指派方法",
    "Automatically assign participants" : "自动指派参与者",
    "Manually assign participants" : "手动指派参与者",
    "Allow participants to choose" : "允许参与者选择",
    "Create rooms" : "创建聊天室",
    "Confirm" : "确认",
    "Create breakout rooms" : "创建分组讨论室",
    "Reset" : "重置",
    "Delete breakout rooms" : "删除分组讨论室",
    "Room {roomNumber}" : "聊天室{roomNumber}",
    "Current breakout rooms and settings will be lost" : "目前的分组讨论室和设置将会丢失",
    "Cancel" : "取消",
    "Unassigned participants" : "未指派的参与者",
    "Back" : "返回",
    "Assign" : "指派",
    "Add participant \"{user}\"" : "添加参与者“{user}”",
    "Now" : "现在",
    "Invalid calendar selected" : "所选日历无效",
    "Invalid start time selected" : "所选开始时间无效",
    "Invalid end time selected" : "所选结束时间无效",
    "Unknown error occurred" : "发生未知错误",
    "Sending no invitations" : "不发送邀请",
    "{participant0} will receive an invitation" : "{participant0} 将收到邀请",
    "{participant0} and {participant1} will receive invitations" : "{participant0} 和 {participant1} 将收到邀请",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}、{participant1} 和其他 %n 人将收到邀请"],
    "Invite {user}" : "邀请 {user}",
    "Invite all users and emails in this conversation" : "邀请此对话中的所有用户和电子邮件",
    "Meeting created" : "会议已创建",
    "Upcoming meetings" : "预定的会议",
    "Loading …" : "正在加载…",
    "No upcoming meetings" : "没有预定的会议",
    "Schedule a meeting" : "安排会议",
    "Meeting title" : "会议标题",
    "From" : "来自",
    "To" : "给",
    "Calendar" : "日历",
    "Attendees" : "参加者",
    "No other participants to send invitations to." : "没有其他参与者可以向其发送邀请。",
    "Add attendees" : "添加参加者",
    "Save" : "保存",
    "Search participants" : "搜索参与者",
    "No results" : "没有结果",
    "Done" : "完成",
    "Disable live transcription" : "禁用实时转录",
    "Enable live transcription (generated by AI)" : "启用实时转录（由 AI 生成）",
    "Enable live transcription (Live transcriptions app is not installed)" : "启用实时转录（未安装实时转录应用）",
    "Disable live translation" : "禁用实时翻译",
    "Enable live translation (generated by AI)" : "启用实时翻译（由 AI 生成）",
    "Original language" : "原始语言",
    "Live translations app is not installed" : "未安装实时翻译应用",
    "Original language: {languageName}" : "原始语言：{languageName}",
    "Translated language" : "翻译语言",
    "Translated language: {languageName}" : "翻译语言：{languageName}",
    "Raise hand" : "举起手 ",
    "Raise hand (R)" : "举起手 (R)",
    "Lower hand" : "放下手 ",
    "Lower hand (R)" : "放下手 (R)",
    "Exit full screen (F)" : "退出全屏（F）",
    "Full screen (F)" : "全屏（F）",
    "Speaker view" : "扬声器视图",
    "Grid view" : "网格视图",
    "Error when trying to load the available live transcription languages" : "尝试加载可用的实时转录语言时出错",
    "Failed to enable live transcription" : "无法启用实时转录",
    "Failed to enable live translations" : "无法启用实时翻译",
    "Failed to disable live translations" : "无法禁用实时翻译",
    "Recording consent is required" : "需要同意录制",
    "This conversation is read-only" : "此对话是只读的",
    "Conversation not found or not joined" : "未找到或未加入对话",
    "Lobby is still active and you're not a moderator" : "大厅仍然活跃，您不是主持人",
    "Connection failed" : "连接失败",
    "Reload" : "重新加载",
    "{nickName} raised their hand." : "{nickName} 举手。",
    "A participant raised their hand." : "一位参与者举手。 ",
    "Collapse stripe" : "折叠条纹",
    "Expand stripe" : "展开条纹",
    "Previous page of videos" : "视频上一页 ",
    "Next page of videos" : "视频下一页",
    "Connecting …" : "正在连接…",
    "Calling …" : "正在呼叫…",
    "Waiting for {user} to join the call" : "等待{user}加入通话",
    "Waiting for others to join the call …" : "等待其他人加入通话 ...",
    "You can invite others in the participant tab of the sidebar" : "您可以在侧栏的参与者选项卡中邀请其他人",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "您可以在侧边栏的参与者标签中邀请其他人或分享此链接以邀请其他人！",
    "Share this link to invite others!" : "分享这个链接来邀请其他人！",
    "Copy link" : "复制链接",
    "You are not allowed to enable audio" : "你不被允许启用音频",
    "No audio. Click to select device" : "没有音频。点击以选择设备",
    "Mute audio" : "静音",
    "Mute audio (M)" : "静音音频 （M）",
    "Unmute audio" : "取消静音",
    "Unmute audio (M)" : "取消静音音频 （M）",
    "None" : "无",
    "Select a microphone" : "选择麦克风",
    "Select a speaker" : "选择扬声器",
    "Microphone settings" : "麦克风设置",
    "Check devices" : "检查设备",
    "Access to camera was denied" : "对摄像头的访问被拒绝",
    "Error while accessing camera: It is likely in use by another program" : "访问摄像头时出现错误：它可能正在被另一个程序使用",
    "Error while accessing camera" : "访问摄像头时出错",
    "You have been muted by a moderator" : "您已被主持人静音",
    "Hide presenter video" : "隐藏演示者视频",
    "You are not allowed to enable video" : "你不被允许启用视频",
    "No video. Click to select device" : "没有视频。点击以选择设备",
    "Disable video" : "禁用视频",
    "Disable video (V)" : "禁用视频 (V)",
    "Enable video" : "启用视频",
    "Enable video (V)" : "启用视频 (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "启用时评 - 首次启用视频时，您的连接会短暂中断",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "启用视频 (V) - 首次启用视频时，您的连接将短暂中断",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "启用视频。当您第一次启用视频时您的连接将会被短暂中断",
    "Select a video device" : "选择视频设备",
    "Show presenter" : "显示演示者",
    "You" : "您",
    "Mute" : "静音",
    "Muted" : "已静音",
    "Show screen" : "显示屏幕",
    "Stop following" : "取消关注",
    "Connection could not be established …" : "无法建立连接",
    "Connection was lost and could not be re-established …" : "连接丢失且无法被重新建立",
    "Connection could not be established. Trying again …" : "无法建立连接。再次尝试中…",
    "Connection lost. Trying to reconnect …" : "连接丢失。尝试重新连接…",
    "Connection problems …" : "连接问题…",
    "Collapse" : "折叠",
    "Expand" : "展开",
    "You need to be logged in to upload files" : "您需要登录以上传文件",
    "Drop your files to upload" : "拖放您的文件以上传",
    "Conversation messages" : "对话消息",
    "Scroll to bottom" : "滚动到底部",
    "Post message" : "发送消息",
    "Federated conversation" : "联合对话",
    "Public conversation" : "公开对话",
    "Favorite" : "收藏",
    "Banned users" : "已封禁用户",
    "Manage the list of banned users in this conversation." : "管理此对话中已封禁用户列表。",
    "Manage bans" : "管理封禁",
    "No banned users" : "没有已封禁用户",
    "Banned by:" : "封禁者：",
    "Date:" : "日期：",
    "Note:" : "说明：",
    "Hide details" : "隐藏详情",
    "Show details" : "显示详情",
    "Unban" : "取消封禁",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "您可以在{linkstart}日历 ↗{linkend} 中更改标题和描述。",
    "Error while updating conversation name" : "更新对话名称时出错",
    "Error while updating conversation description" : "更新对话描述时出错 ",
    "Enter a name for this conversation" : "输入此对话的名称",
    "Edit conversation name" : "编辑对话名称",
    "Edit conversation description" : "编辑对话描述",
    "Enter a description for this conversation" : "为这个对话输入一个描述 ",
    "Picture" : "图片",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "可在此对话中启用以下机器人。要安装其他机器人，请联系管理员。",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "此服务器上没有安装机器人。要安装机器人，请联系管理员。",
    "Disable" : "禁用",
    "Enable" : "开启",
    "The bot is not available anymore" : "机器人不再可用",
    "Breakout rooms" : "分组讨论室",
    "Manage breakout rooms" : "管理分组讨论室",
    "Set up breakout rooms for this conversation" : "为此对话设置分组讨论室",
    "Please select a valid PNG or JPG file" : "请选择有效的PNG或JPG文件",
    "Choose your conversation picture" : "选择您的对话图片",
    "Choose" : "选择",
    "Error setting conversation picture" : "设置对话图片时出错",
    "Could not set the conversation picture: {error}" : "无法设定对话图片：{error}",
    "Error cropping conversation picture" : "裁剪对话图片时出错",
    "Error removing conversation picture" : "移除对话图片时出错",
    "Set emoji as conversation picture" : "将表情符号设置为对话图片",
    "Set background color for conversation picture" : "设置对话图片的背景颜色",
    "Upload conversation picture" : "上传对话图片",
    "Choose conversation picture from files" : "从文件中选择对话图片",
    "Remove conversation picture" : "移除对话图片",
    "The file must be a PNG or JPG" : "文件必须是 PNG 或 JPG 格式",
    "Set picture" : "设置图片",
    "Default permissions modified for {conversationName}" : "更改了 {conversationName} 的默认权限",
    "Could not modify default permissions for {conversationName}" : "无法更改 {conversationName} 的默认权限",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "编辑此对话中参与者的默认权限。这些设置不会影响版主。",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "每次在此部分修改权限时，之前指派给各个参与者的自定义权限都将丢失。",
    "All permissions" : "所有权限",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "与会者具有发起通话、加入通话、开启音频、视频和共享屏幕等权限。",
    "Participants can use all available features." : "参与者可以使用所有可用功能。",
    "Restricted" : "受限",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "在版主手动授权之前，与会者可以加入通话，但不能开启音频、视频也不能共享屏幕",
    "Participants get a reduced feature set until a moderator manually grants additional permissions." : "在主持人手动授予额外权限之前，参与者只能使用部分功能。",
    "Advanced permissions" : "高级权限",
    "Edit permissions" : "编辑权限",
    "Conversation settings" : "对话设置",
    "Basic Info" : "基本信息",
    "Personal" : "个人",
    "Moderation" : "限制",
    "Setup overview" : "设置概览",
    "Live transcription" : "实时转录",
    "Live transcriptions app is not installed" : "未安装实时转录应用",
    "Enable live transcription" : "启用实时转录",
    "Breakout Rooms" : "分组讨论室",
    "Matterbridge" : "Matterbridge ",
    "Bots" : "机器人",
    "Danger zone" : "危险区域",
    "Archive conversation" : "存档对话",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "已存档的对话默认在对话列表中隐藏。但是，当您搜索对话名称或访问已存档的对话列表时，它们仍然会出现。",
    "Do you really want to leave \"{displayName}\"?" : "是否确定要离开“{displayName}”？",
    "You can archive this conversation instead." : "您可以改为将此对话存档。",
    "Leave conversation" : "离开对话",
    "You need to promote a new moderator before you can leave the conversation" : "在您离开对话之前需要推举一位新的主持人",
    "Delete conversation" : "删除对话",
    "Do you really want to delete \"{displayName}\"?" : "是否确定要删除“{displayName}”？",
    "Error while deleting conversation" : "删除对话时出错 ",
    "Delete all chat messages" : "删除所有聊天消息",
    "Do you really want to delete all messages in \"{displayName}\"?" : "是否确定要删除“{displayName}”中的所有消息？",
    "Error while clearing chat history" : "清除聊天消息时出错",
    "Be careful, these actions cannot be undone." : "小心，这些操作无法被撤销。",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "一旦离开对话，要重新加入已关闭的谈话，需要一个邀请。公开对话可以在任何时候重新加入。",
    "Permanently delete this conversation." : "永久删除此对话。",
    "Delete chat messages" : "删除聊天消息",
    "Permanently delete all the messages in this conversation." : "永久删除此对话中的所有消息",
    "_%n hour_::_%n hours_" : ["%n 小时"],
    "_%n day_::_%n days_" : ["%n 天"],
    "_%n week_::_%n weeks_" : ["%n 周"],
    "Custom expiration time" : "自定义过期时间",
    "Message expiration disabled" : "消息过期已禁用",
    "Message expiration set: {duration}" : "消息过期设置：{duration}",
    "Error when trying to set message expiration" : "尝试设置消息过期时发生错误",
    "Message expiration" : "消息过期",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "可指定聊天消息在一定时间后过期。注意：聊天中分享的文件不会被从所有者一方删除，但是会被从对话中取消分享。",
    "Set message expiration" : "设置消息过期时间",
    "Current message expiration" : "当前的消息过期时间",
    "Password copied to clipboard" : "密码已复制到剪贴板",
    "Password could not be copied" : "无法复制密码",
    "Guest access" : "访客访问",
    "Breakout rooms are not allowed in public conversations." : "公开对话中不允许分组会议室。",
    "Allow guests to join this conversation via link" : "允许访客通过链接加入此对话",
    "Password protection" : "密码保护",
    "This conversation is password-protected. Guests need password to join" : "此对话受密码保护，访客需要密码才能加入",
    "Password protection is needed for public conversations" : "公开对话需要密码保护",
    "Set a password" : "设置密码",
    "Change password" : "更改密码",
    "Enter new password" : "输入新密码",
    "Save password" : "保存密码",
    "Copy password" : "复制密码",
    "Guests are allowed to join this conversation via link" : "访客可以通过链接加入此对话",
    "Guests are not allowed to join this conversation" : "访客不能加入此对话",
    "Resend invitations" : "重新发送邀请",
    "This conversation is open to both registered users and users created with the Guests app" : "此对话对已注册用户和使用访客应用建立的应用开放",
    "This conversation is open to registered users" : "此对话对已注册用户开放",
    "This conversation is limited to the current participants" : "此对话仅对当前参与者开放",
    "You opened the conversation to both registered users and users created with the Guests app" : "你向已注册用户和通过访客应用创建的账号开放了此对话",
    "Error occurred when opening or limiting the conversation" : "开放或限制对话时发生错误",
    "Open conversation to registered users, showing it in search results" : "向注册用户开放对话并在搜索结果中显示",
    "Also open to users created with the Guests app" : "同时对使用访客应用创建的账号开放",
    "Open conversation" : "开放对话",
    "Set language spoken in calls" : "设置通话语言",
    "Languages could not be loaded" : "无法加载语言",
    "Loading languages …" : "正在加载语言 …",
    "Invalid language" : "语言无效",
    "Default language (English)" : "默认语言（英语）",
    "Default live transcription language set" : "默认实时转录语言集",
    "Live transcription language set: {languageName}" : "实时转录语言集：{languageName}",
    "Error when trying to set live transcription language" : "尝试设置实时转录语言时出错",
    "Start time: {date}" : "开始时间：{date}",
    "Start time has been updated" : "开始时间已更新",
    "Error occurred while updating start time" : "更新开始时间时发生错误 ",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "启用大厅将会从正在进行的对话中移除非主持人",
    "Enable lobby, restricting the conversation to moderators" : "启用大厅，将对话限制到与主持人之间",
    "Meeting start time" : "会议开始时间",
    "Start time (optional)" : "开始时间（可选）",
    "Import email participants" : "导入电子邮件参与者",
    "You can import a list of email participants from a CSV file." : "您可以从 CSV 文件导入电子邮件参与者列表。",
    "Poll drafts" : "投票草稿",
    "Browse poll drafts" : "浏览投票草稿",
    "Error occurred when locking the conversation" : "锁定对话时发生错误 ",
    "Error occurred when unlocking the conversation" : "解锁对话时发生错误 ",
    "Lock conversation" : "锁定对话",
    "This will also terminate the ongoing call." : "这也将终止正在进行的通话。",
    "Lock the conversation to prevent anyone to post messages or start calls" : "锁定对话防止任何人发布消息或开始通话。",
    "Edit" : "编辑",
    "More information" : "更多信息",
    "Delete" : "删除",
    "Add new bridged channel to current conversation" : "向当前对话添加新的桥接通道",
    "unknown state" : "未知状态",
    "running" : "运行中",
    "not running, check Matterbridge log" : "未在运行，检查 Matterbridge 日志",
    "not running" : "未在运行",
    "Bridge saved" : "网桥已保存",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "你可以使用 Matterbridge 桥接来自各种即时消息传递系统的频道。",
    "More info on Matterbridge" : "更多关于Matterbridge的信息",
    "Messaging systems" : "消息系统",
    "Enable bridge" : "启用桥接",
    "Show Matterbridge log" : "显示 Matterbridge 日志",
    "Log content" : "日志内容",
    "Only moderators are allowed to mention @all" : "仅允许主持人提及 @all",
    "All participants are allowed to mention @all" : "所有参与者都可以提及 @all",
    "Participants are now allowed to mention @all." : "现在允许参与者提及 @all。",
    "Mentioning @all has been limited to moderators." : "提及 @all 仅限于主持人。",
    "Allow participants to mention @all" : "允许参与者提及 @all",
    "Mention permissions" : "提及权限",
    "Notifications" : "通知",
    "Notify about calls in this conversation" : "关于此对话中呼叫的通知",
    "Important conversation" : "重要对话",
    "\"Do not disturb\" user status is ignored for important conversations" : "重要对话忽略“勿扰”用户状态",
    "Sensitive conversation" : "敏感对话",
    "Message preview will be disabled in conversation list and notifications" : "将在对话列表和通知中禁用消息预览",
    "Recording consent is required for calls in this conversation" : "在此对话中通话需要提供录制许可",
    "Recording consent is not required for calls in this conversation" : "在此对话中通话无需提供录制许可",
    "Recording consent requirement was updated" : "已更新录制许可要求",
    "Error occurred while updating recording consent" : "更新录制同意时出错",
    "Recording Consent" : "录制许可",
    "Recording consent cannot be changed once a call or breakout session has started." : "通话或分组会议开始后，录制同意书就不能更改。",
    "Require recording consent before joining call in this conversation" : "在此对话中加入通话前要求准许录制",
    "Recording consent is required for all calls" : "所有通话都需要提供录制许可",
    "SIP dial-in is now possible without PIN requirement" : "现在无需 PIN 即可进行 SIP 拨号",
    "SIP dial-in is now enabled" : "启用了 SIP 拨号 ",
    "SIP dial-in is now disabled" : "禁用了 SIP 拨号",
    "Error occurred when enabling SIP dial-in" : "启用 SIP 拨号时发生错误",
    "Error occurred when disabling SIP dial-in" : "禁用 SIP 拨号时发生错误",
    "Phone and SIP dial-in" : "电话和 SIP 拨号",
    "Enable phone and SIP dial-in" : "启用电话和 SIP 拨号",
    "Allow to dial-in without a PIN" : "允许在没有 PIN 的情况下拨号",
    "Ongoing" : "正在进行",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n 人接受"],
    "_%n person declined_::_%n people declined_" : ["%n 人拒绝"],
    "_and %n other attachment_::_and %n other attachments_" : ["以及另外 %n 个附件"],
    "With {displayName}" : "有 {displayName}",
    "In {conversation}" : "在 {conversation} 中",
    "View attachment" : "查看附件",
    "Join" : "加入",
    "View conversation" : "查看对话",
    "View event on Calendar" : "在日历上查看活动",
    "Error while creating the conversation" : "创建对话时出错",
    "Hello, {displayName}" : "您好，{displayName}",
    "Start meeting now" : "立即开始会议",
    "Give your meeting a title" : "为您的会议命名",
    "Create and copy link" : "创建并复制链接",
    "Create a new conversation" : "创建一个新对话",
    "Join open conversations" : "加入公开对话",
    "Call a phone number" : "呼叫电话号码",
    "Scroll backward" : "向后滚动",
    "Scroll forward" : "向前滚动",
    "Schedule meetings" : "安排会议",
    "You don't have any upcoming meetings" : "您没有任何预定的会议",
    "Calendar events with a conversation link as the location are shown here" : "此处显示的是将对话链接设为位置的日历活动",
    "Open calendar" : "打开日历",
    "Unread mentions" : "未读的提及",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "提及您的消息会显示在此处。您可以通过输入 @ 后跟他们的名称来提及他们",
    "Upcoming reminders" : "预定的提醒",
    "Message reminders" : "消息提醒",
    "Set a reminder on a message to be notified" : "在要通知的消息上设置提醒",
    "Start a group conversation" : "开始群组对话",
    "Create conversation" : "创建对话",
    "Enter your name" : "输入你的名字",
    "Submit name and join" : "设置名称并加入",
    "Do you already have an account?" : "已经有账号了？",
    "Log in" : "登录",
    "Error while verifying uploaded file" : "验证上传文件时出错",
    "Uploaded file is verified" : "已验证上传的文件",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "内容格式为逗号分隔值（CSV）：<br/> - 标题行是必需的，必须与<samp>“姓名”、“电子邮件”</samp>或仅<samp>“电子邮件”</samp>匹配。<br/> - 每行一个条目（例如<samp>“John Doe\",\"john@example.tld\"</samp>)",
    "Participants added successfully" : "参与者添加成功",
    "Error while adding participants" : "添加参与者时出错",
    "Import a file" : "导入文件",
    "Browse" : "浏览",
    "Verifying uploaded file …" : "正在验证上传的文件…",
    "This might take a moment" : "这可能需要一段时间",
    "Send invitations" : "发送邀请",
    "_%n invalid email_::_%n invalid emails_" : [" %n 个无效的电子邮件"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n 个电子邮件已导入或重复"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["可以发送 %n 个邀请"],
    "An error occurred while calling a phone number" : "呼叫电话号码时发生错误",
    "Phone number could not be called: {error}" : "无法呼叫电话号码： {error}",
    "Phone number could not be called" : "无法呼叫电话号码",
    "Search participants or phone numbers" : "搜索参与者或电话号码",
    "Creating the conversation …" : "正在建立对话……",
    "Mark as read" : "标为已读",
    "Mark as unread" : "标为未读",
    "Remove from favorites" : "从收藏夹移除",
    "Add to favorites" : "添加到收藏夹",
    "Unarchive conversation" : "取消归档对话",
    "Ignore \"Do not disturb\"" : "忽略“勿扰”",
    "You need to promote a new moderator before you can leave the conversation." : "在您离开对话之前您需要推举一位新的主持人。",
    "Conversation actions" : "对话操作",
    "Notify about calls" : "通话通知",
    "Hide message text" : "隐藏消息文本",
    "Pending invitations" : "待处理的邀请",
    "Join conversations from other servers" : "加入其他服务器的对话",
    "From {user} at {remoteServer}" : "来自 {remoteServer} 的 {user}",
    "Decline invitation" : "拒绝邀请",
    "Accept invitation" : "接受邀请",
    "No pending invitations" : "没有待处理的邀请",
    "Home" : "首页",
    "Unread" : "未读",
    "Mentions" : "提及",
    "Meetings" : "会议",
    "Sort conversations" : "排序对话",
    "By recent activity" : "按最近的活动",
    "Alphabetically" : "按字母顺序",
    "Do not group by type" : "不按类型分组",
    "Show private ones first" : "先显示私人对话",
    "Show group ones first" : "先显示群组对话",
    "No followed threads" : "没有关注的帖子",
    "No matches found" : "未找到匹配项",
    "No conversations found" : "未找到对话",
    "You have no archived conversations." : "您没有已存档的对话。",
    "Subscribe to an existing thread or start your own." : "订阅现有的帖子或开始自己的帖子。",
    "You have no unread mentions." : "无未读的提及",
    "You have no unread messages." : "无未读消息",
    "An error occurred while performing the search" : "执行搜索时出错",
    "Conversation list" : "对话列表",
    "Filter conversations by" : "按以下条件筛选对话",
    "Unread messages" : "未读消息",
    "Meeting conversations" : "会议对话",
    "Clear filters" : "清除过滤器",
    "New personal note" : "新建个人笔记",
    "SIP backend is not installed" : "未安装 SIP 后端",
    "Back to conversations" : "返回对话",
    "Archived conversations" : "已存档的对话",
    "Threads" : "帖子‌",
    "Clear filter" : "清除筛选",
    "Show more threads" : "显示更多帖子‌",
    "App settings" : "应用设置",
    "Users" : "用户",
    "Groups" : "分组",
    "Teams" : "团队",
    "Federated users" : "联合用户",
    "New private conversation" : "新私人对话",
    "Other sources" : "其他来源",
    "Open conversations" : "开启对话",
    "No search results" : "无搜索结果",
    "Users, groups and teams" : "用户、群组和团队",
    "Users and groups" : "用户和群组",
    "Users and teams" : "用户和团队",
    "Groups and teams" : "群组和团队",
    "New group conversation" : "新群组对话",
    "The meeting will start soon" : "会议不久后开始",
    "This meeting is scheduled for {startTime}" : "此会议定于 {startTime} 开始",
    "You are currently waiting in the lobby" : "您当前正在大厅等待。",
    "Enable noise suppression" : "启用噪声抑制",
    "Reduce background noises for better voice quality" : "减少背景噪音，提高语音质量",
    "Enable echo cancellation" : "启用回声消除",
    "Minimize echo effect from own surrounding" : "尽量减少自身周围环境的回声效应",
    "Enable auto gain control" : "启用自动增益控制",
    "Dynamically adjust microphone volume for consistent level" : "动态调节麦克风音量以保持音量稳定",
    "Select microphone" : "选择麦克风",
    "No microphone available" : "麦克风不可用",
    "Select speaker" : "选择扬声器",
    "No speaker available" : "没有扬声器可用",
    "Select camera" : "选择摄像头",
    "No camera available" : "摄像头不可用",
    "Select a device" : "选择设备",
    "Playing …" : "正在播放…",
    "Test speakers" : "测试扬声器",
    "Test" : "测试",
    "Devices" : "设备",
    "Backgrounds" : "背景图片",
    "No audio" : "无音频",
    "No camera" : "没有摄像头",
    "Display video as you will see it (mirrored)" : "显示您将看到的视频（镜像）",
    "Display video as others will see it" : "以其他人看到的方式显示视频",
    "Calls are not supported in your browser" : "您的浏览器不支持呼叫",
    "Access to microphone is only possible with HTTPS" : "麦克风只能通过 HTTPS 协议访问",
    "Access to microphone was denied" : "无权访问麦克风",
    "Error while accessing microphone" : "访问麦克风时出错",
    "Access to camera is only possible with HTTPS" : "摄像头只能通过 HTTPS 协议访问",
    "The call is being recorded." : "通话正在被录制",
    "The call might be recorded." : "通话可能被录制",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "录制内容可能包括您的声音、摄像头的画面，以及屏幕分享的内容。要加入通话，您需要同意录制。",
    "Give consent to the recording of this call" : "您需要同意录制此通话",
    "Show more info" : "显示更多信息",
    "Audio is not available" : "音频不可用",
    "Video is not available" : "视频不可用",
    "Start recording immediately with the call" : "通话开始的同时开始录制",
    "Recording backend is not installed" : "未安装录制后端",
    "Notify all participants about this call" : "通知所有参与者关于此通话",
    "Apply settings" : "应用设置",
    "Select virtual office background" : "选择虚拟办公室背景",
    "Select virtual home background" : "选择虚拟家庭背景",
    "Select virtual abstract background" : "选择虚拟抽象背景",
    "Select virtual beach background" : "选择虚拟海滩背景",
    "Select virtual park background" : "选择虚拟公园背景",
    "Select virtual theater background" : "选择虚拟剧院背景",
    "Select virtual library background" : "选择虚拟图书馆背景",
    "Select virtual space station background" : "选择虚拟太空站背景",
    "Error while uploading the file" : "上传文件时出错",
    "Select a file" : "选择文件",
    "Invalid path selected" : "选择的路径无效",
    "Select virtual background from file {fileName}" : "从{fileName}文件中选择背景",
    "Blur" : "模糊",
    "Upload" : "上传",
    "Files" : "文件",
    "(editing)" : "（编辑中）",
    "(edited)" : "（已编辑）",
    "The message has expired or has been deleted" : "消息已过期或已被删除。",
    "Cancel quote" : "取消引用",
    "24 hours" : "24 小时 ",
    "7 days" : "7 天",
    "30 days" : "30 天",
    "Until unpin" : "直到取消置顶",
    "Clear reminder – {timeLocale}" : "取消提醒 – {timeLocale}",
    "Edited by {actor}" : "由 {actor} 编辑",
    "Pinned by you" : "由您置顶",
    "Pinned by {actor}" : "由 {actor} 置顶",
    "Until {absoluteDate}" : "直到 {absoluteDate}",
    "Message text copied to clipboard" : "消息文本已复制到剪贴板",
    "Message text could not be copied" : "无法复制消息文本",
    "Message forwarded to \"Note to self\"" : "消息已转发到“自我备注”",
    "Error while forwarding message to \"Note to self\"" : "将消息转发到“自我备注”时出错",
    "A reminder was successfully removed" : "提醒删除成功",
    "Error occurred when removing a reminder" : "移除提醒时出错",
    "A reminder was successfully set at {datetime}" : "于 {datetime} 的提醒设置成功",
    "Error occurred when creating a reminder" : "创建提醒时出错",
    "Add a reaction to this message" : "添加对此消息的回应",
    "Reply" : "回复",
    "More actions" : "更多操作 ",
    "Set reminder" : "设置提醒",
    "Pin message" : "置顶消息",
    "Unpin message" : "取消置顶消息",
    "Reply privately" : "私下回复",
    "Edit message" : "编辑消息",
    "Copy message" : "复制消息",
    "Copy message link" : "复制消息链接",
    "Go to file" : "前往文件",
    "Download file" : "下载文件",
    "Go to thread" : "转到帖子",
    "Edit thread details" : "编辑帖子详情",
    "Forward message" : "转发消息",
    "Translate" : "翻译",
    "Set custom reminder" : "设置自定义提醒",
    "Keep pinned for" : "保持置顶",
    "Set custom period" : "设置自定义时段",
    "Close reactions menu" : "关闭回应菜单",
    "React with {emoji}" : "使用 {emoji} 回应",
    "React with another emoji" : "使用其他表情符号做出回应",
    "Choose a conversation to forward the selected message." : "选择对话来转发所选消息",
    "Error while forwarding message" : "转发消息时出错",
    "The message has been forwarded to {selectedConversationName}" : "已转发此消息至{selectedConversationName}",
    "Dismiss" : "关闭",
    "Go to conversation" : "转到对话",
    "Detect language" : "检测语言",
    "The message could not be translated" : "无法翻译信息",
    "Translation copied to clipboard" : "翻译已复制到剪贴板",
    "Translation could not be copied" : "无法复制翻译。",
    "Translate message" : "翻译信息",
    "Source language to translate from" : "要翻译的来源语言",
    "Translate from" : "翻译至",
    "Target language to translate into" : "要翻译的目标语言",
    "Translate to" : "翻译至",
    "Translating" : "正在翻译",
    "This translation is AI generated and may contain mistakes." : "此翻译是 AI 生成的，可能包含错误。",
    "Copy translated text" : "复制已翻译的文字",
    "Error when scheduling the message" : "安排消息时出错",
    "Reschedule" : "重新安排",
    "Send now" : "立即发送",
    "Choose a time" : "选择时间",
    "Send at custom time" : "在自定义时间发送",
    "Will be sent without notification" : "将不另行通知发送",
    "Message read by everyone who shares their reading status" : "消息被每个分享他们阅读状态的人读取",
    "Message sent" : "消息已发送",
    "Sent without notification" : "发送而不通知",
    "Deleting message" : "正在删除消息",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "消息已成功删除，但已配置机器人或 Matterbridge，消息可能已分发到其他服务",
    "Message deleted successfully" : "成功删除了消息",
    "Message could not be deleted because it is too old" : "消息太旧，无法删除",
    "Only normal chat messages can be deleted" : "只能删除正常的聊天消息 ",
    "An error occurred while deleting the message" : "删除消息时发生错误 ",
    "Pinned" : "已置顶",
    "Your browser does not support playing audio files" : "你的浏览器不支持播放音频文件",
    "Contact" : "联系人",
    "{stack} in {board}" : "{stack} 于 {board}",
    "Deck Card" : "看板卡片",
    "Remove {fileName}" : "删除 {fileName}",
    "Open this location in OpenStreetMap" : "在 OpenStreetMap 中打开此位置",
    "_%n reply_::_%n replies_" : ["%n 个回复"],
    "Sending message" : "正在发送消息",
    "Failed to send the message. Click to try again" : "消息发送失败。点击重试",
    "Not enough free space to upload file" : "没有足够的空间上传文件",
    "You cannot send messages to this conversation at the moment" : "您目前无法向此对话发送消息",
    "Could not update the message" : "无法更新消息",
    "Reply to thread \"{threadTitle}\"" : "回复帖子“{threadTitle}”",
    "_You voted • %n vote_::_You voted • %n votes_" : ["您已投票 • %n 票"],
    "You voted" : "您已投票",
    "_Click to vote • %n vote_::_Click to vote • %n votes_" : ["点击投票 • %n 票"],
    "Click to vote" : "点击投票",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["投票草稿 • %n 个选项"],
    "_%n vote_::_%n votes_" : ["%n 票"],
    "Edit poll draft" : "编辑投票草稿",
    "Delete poll draft" : "删除投票草稿",
    "Open poll" : "公开投票",
    "Closed poll" : "非公开投票",
    "See results" : "查看结果",
    "Reactions" : "回应",
    "No permission to post reactions in this conversation" : "无权限在此对话中发布回应",
    "and {participant}" : "与 {participant}",
    "_and %n other participant_::_and %n other participants_" : ["及其他 %n 位参与者"],
    "Show all reactions" : "显示所有回应",
    "Add more reactions" : "添加更多回应",
    "Show or collapse system messages" : "显示或折叠系统消息",
    "No messages" : "没有消息",
    "All messages have expired or have been deleted." : "所有消息都已过期或已被删除。",
    "Generate summary with AI" : "使用 AI 生成摘要",
    "{author} (pinned by you)" : "{author}（由您置顶）",
    "{author} (pinned by {actor})" : "{author}（由 {actor} 置顶）",
    "Unpin" : "取消置顶",
    "Cancel search" : "取消搜索",
    "Add a phone number" : "添加电话号码",
    "Error: A password is required to create the conversation." : "错误：创建对话需要密码。",
    "All set, the conversation \"{conversationName}\" was created." : "一切就绪，对话“{conversationName}”已创建",
    "Create a new group conversation" : "建立新的群组对话",
    "Add participants" : "添加参与者",
    "Maximum length exceeded ({maxlength} characters)" : "超过最大长度（{maxlength} 个字符）",
    "Conversation type" : "对话类型",
    "Conversation visibility" : "对话可见性",
    "Allow guests to join via link" : "允许访客通过链接加入",
    "Enter password" : "输入密码",
    "This conversation has been locked" : "此对话已锁定",
    "No permission to post messages in this conversation" : "无权限在此对话中发布消息",
    "Joining conversation …" : "正在加入对话…",
    "Write a message without notification" : "写消息而不通知",
    "Create a thread silently" : "静默创建帖子",
    "Create a thread" : "创建帖子",
    "Send message silently" : "静默发送消息",
    "Send message" : "发送消息",
    "Send without notification" : "发送而不通知",
    "The participant will not be notified about new messages" : "此参与者将不会收到新消息的通知",
    "Participants will not be notified about new messages" : "参与者将不会收到新消息的通知",
    "Message will be sent {datetimeString}" : "消息将于 {datetimeString} 发送",
    "Thread title is required" : "帖子标题为必填项",
    "Message text is required" : "消息文本为必填项",
    "The message could not be edited" : "无法编辑消息",
    "File to share" : "要分享的文件",
    "File upload is not available in this conversation" : "此对话中无法上传文件",
    "Message was successfully scheduled" : "消息已成功安排",
    "Add emoji" : "添加 emoji",
    "Adding a mention will only notify users who did not read the message." : "添加提及只会通知未阅读消息的用户。",
    "Thread title" : "帖子‌标题",
    "Send later" : "稍后发送",
    "Show scheduled messages" : "显示已安排的消息",
    "Cancel editing" : "取消编辑",
    "Schedule message" : "安排消息",
    "{user} is out of office and might not respond." : "{user} 不在办公室，可能不会回复。",
    "Absence period: {startDate} - {endDate}" : "缺勤时段：{startDate} - {endDate}",
    "Replacement:" : "接替者：",
    "Share from {nextcloud}" : "从{nextcloud}分享",
    "Share from Files" : "从文件共享",
    "Share files to the conversation" : "分享文件到对话",
    "Upload from device" : "从设备上传",
    "Create new poll" : "创建新的投票",
    "Smart picker" : "智能选择器",
    "Record voice message" : "录制语音消息",
    "End recording and send" : "结束录音并发送",
    "Dismiss recording" : "取消录音",
    "Access to the microphone was denied" : "对麦克风的访问被拒绝",
    "Microphone either not available or disabled in settings" : "麦克风不可用或者在设置中被禁用",
    "Error while recording audio" : "录制音频时出错",
    "Voice message {time} ({conversation})" : "语音信息 {time}（{conversation}）",
    "Generating summary of unread messages …" : "正在生成未读消息的摘要…",
    "Summary is AI generated and might contain mistakes" : "摘要是 AI 生成的，可能包含错误",
    "Error occurred during a summary generation" : "生成摘要时出错",
    "New file" : "新文件",
    "Blank" : "空白",
    "Error while creating file" : "创建文件时出错",
    "Create and share a new file" : "创建及分享新文档",
    "Name of the new file" : "新文件的名称",
    "Create file" : "创建文件",
    "Someone is typing …" : "有人在输入……",
    "{user1} is typing …" : "{user1}在输入……",
    "{user1} and {user2} are typing …" : "{user1}和{user2}在输入……",
    "{user1}, {user2} and {user3} are typing …" : "{user1}、{user2}和{user3}正在输入……",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}、{user2}、{user3} 和其他 %n 人正在输入…"],
    "Add more files" : "添加更多文件",
    "Send" : "发送",
    "In this conversation <strong>{user}</strong> can:" : "此对话中，<strong>{user}</strong>可以：",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "编辑 <strong>{conversationName}</strong>中参与者的默认权限",
    "Start a call" : "启动通话",
    "Skip the lobby" : "跳过大厅",
    "Can post messages" : "可以发布消息",
    "Can post messages and reactions" : "可以发布消息和回应",
    "Can add reactions" : "可以添加回应",
    "Enable the microphone" : "启用麦克风",
    "Enable the camera" : "启用相机",
    "Share the screen" : "共享屏幕",
    "Update permissions" : "更新权限",
    "Updating permissions" : "正在更新权限",
    "No poll drafts" : "无投票草稿",
    "There is no poll drafts yet saved for this conversation" : "此对话尚未保存投票草稿",
    "Create poll in {name}" : "在 {name} 中创建投票",
    "Create poll" : "创建投票",
    "Error while importing poll" : "导入投票时出错",
    "Question" : "问题",
    "Ask a question" : "提出一个问题",
    "Import draft from file" : "从文件导入草稿",
    "Answers" : "答案",
    "Answer {option}" : "答案{option}",
    "Delete poll option" : "删除投票选项",
    "Add answer" : "添加答案",
    "Settings" : "设置",
    "Anonymous poll" : "匿名投票",
    "Multiple answers" : "多选答案",
    "Save as draft" : "保存为草稿",
    "Export draft to file" : "将草稿导出到文件",
    "_Final results • %n vote_::_Final results • %n votes_" : ["最终结果 • %n 票"],
    "Your vote is anonymous" : "您的投票是匿名的",
    "You voted for this option" : "您投了此选项",
    "End poll" : "結束投票",
    "Change your vote" : "更改您的投票",
    "Withdraw vote" : "撤回投票",
    "Results" : "结果",
    "Voted participants" : "已投票的参与者",
    "Send a message to \"{roomName}\"" : "向“{roomName}”分组讨论室发送消息",
    "Hide list of participants" : "隐藏参与者列表",
    "Show list of participants" : "显示参与者列表",
    "Assistance requested in {roomName}" : "{roomName}请求协助",
    "The message was sent to \"{roomName}\"" : "消息已发送至分组讨论室“{roomName}”",
    "Dismiss request for assistance" : "撤销协助请求",
    "Send message to room" : "发送消息至聊天室",
    "Back to main room" : "回到主聊天室",
    "Back to your room" : "回到您的聊天室",
    "Message all rooms" : "向所有聊天室发送消息",
    "Start session" : "开启会话",
    "Start a call before you start a breakout room session" : "在开启分组讨论室会话之前开始一个通话",
    "Stop session" : "停止会话",
    "The message was sent to all breakout rooms" : "消息已发送至所有分组讨论室",
    "Send a message to all breakout rooms" : "向所有分组讨论室发送消息",
    "Breakout rooms are not started" : "分组讨论室尚未开启",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "没有高性能后端的通话可能会导致连接问题和设备上的高负载。{linkstart}了解更多{linkend}",
    "Talk setup incomplete" : "Talk 设置未完成",
    "Disable lobby" : "禁用大厅",
    "Settings for participant \"{user}\"" : "参与者 \"{user}\" 的设置",
    "Participant \"{user}\"" : "参与者\"{user}\" ",
    "moderator" : "主持人",
    "bot" : "机器人",
    "guest" : "访客",
    "Ringing …" : "正在响铃……",
    "Call rejected" : "通话被拒绝",
    "{time} talking …" : "{time} 说话…",
    "{time} talking time" : "{time} 说话时间",
    "Raised their hand" : "举起了他们的手",
    "Joined with video" : "通过视频加入",
    "Joined via phone" : "通过电话加入",
    "Joined with audio" : "通过音频加入",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "文字的长度必须小于或等于 {maxLength}个字符。您目前的文字长度为{charactersCount}个字符。",
    "Remove group and members" : "移除群组和成员",
    "Remove team and members" : "移除团队和成员",
    "Remove participant" : "移除参与者",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "是否确定要从此对话中移除群组“{displayName}”及其成员？",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "是否确定要从此对话中移除团队“{displayName}”及其成员？",
    "Do you really want to remove {displayName} from this conversation?" : "是否确定要从此对话中移除 {displayName}？",
    "Notification was sent to {displayName}" : "通知已发送给·{displayName}",
    "Could not send notification to {displayName}" : "无法发送通知给{displayName}",
    "Permissions granted to {displayName}" : "已将权限授予 {displayName}",
    "Could not modify permissions for {displayName}" : "无法更改 {displayName} 的权限",
    "Permissions removed for {displayName}" : "移除了 {displayName} 的权限",
    "Permissions set to default for {displayName}" : "{displayName} 权限已设为默认值",
    "Phone number could not be hung up" : "无法挂断电话号码",
    "Phone number could not be put on hold" : "无法保持电话号码",
    "Phone number could not be muted" : "对电话号码静音失败",
    "Phone number could not be unmuted" : "取消电话号码静音失败",
    "DTMF message could not be sent" : "无法发送 DTMF 消息",
    "Phone number copied to clipboard" : "电话号码已复制到剪贴板",
    "Phone number could not be copied" : "无法复制电话号码",
    "in the lobby" : "在大厅",
    "Dial out phone" : "拨打电话",
    "Hang up phone" : "挂断电话",
    "Move back to lobby" : "移回大厅",
    "Move to conversation" : "移至对话",
    "Dial-in PIN" : "拨号 PIN 码",
    "Demote from moderator" : "撤销主持人",
    "Promote to moderator" : "提升为主持人",
    "Resend invitation" : "重新发送邀请",
    "Send call notification" : "发送通话通知",
    "Dial out phone number" : "呼叫的电话号码",
    "Resume call for phone number" : "恢复电话号码的通话",
    "Put phone number on hold" : "将电话置入呼叫保持",
    "Unmute phone number" : "取消电话号码静音",
    "Mute phone number" : "静音电话号码",
    "Copy phone number" : "复制电话号码",
    "Reset custom permissions" : "重置自定义权限",
    "Grant all permissions" : "授予所有权限",
    "Remove all permissions" : "移除所有权限",
    "Also ban from this conversation" : "也从此对话中封禁",
    "Internal note (reason to ban)" : "内部备注（封禁原因）",
    "Remove" : "移除",
    "Permissions modified for {displayName}" : "更改了 {displayName} 的权限",
    "Add users, groups or teams" : "添加用户、群组或团队",
    "Add users or groups" : "增加用户或组",
    "Add users or teams" : "添加用户或团队",
    "Add users" : "添加用户",
    "Add groups or teams" : "添加群组或团队",
    "Add groups" : "添加分组",
    "Add teams" : "添加团队",
    "Add other sources" : "添加其他来源",
    "Add emails" : "添加电子邮件",
    "Integrations" : "集成",
    "Add federated users" : "添加联合用户",
    "Searching …" : "正在搜索 ...",
    "Search for more users" : "搜索更多用户",
    "You can search or add participants via name, email, or Federated Cloud ID" : "您可以通过姓名、电子邮件或联合云 ID 搜索或添加参与者",
    "Search or add participants" : "搜索或添加参与者",
    "Invitation was sent to {actorId}" : "邀请已发送至{actorId}",
    "An error occurred while adding the participants" : "添加参与者时发生错误 ",
    "A new group conversation with selected participant will be created" : "将创建与所选参与者的新群组对话",
    "Participants" : "参与者",
    "Pinned by a deleted user" : "由已删除用户置顶",
    "Participants ({count})" : "参与者数量 ({count})",
    "Open chat" : "开启聊天",
    "You have new unread messages in the chat." : "你在聊天中有新的未读消息",
    "You have been mentioned in the chat." : "你在聊天中被提及",
    "Search messages" : "搜索消息",
    "Chat" : "聊天",
    "Details" : "详情",
    "Shared items" : "已共享项目",
    "Search in {name}" : "在 {name} 中搜索",
    "Threads in {name}" : "{name} 中的帖子‌",
    "{actor} in {conversation}" : "{conversation}中的 {actor}",
    "Search messages …" : "搜索消息…",
    "Search options" : "搜索选项",
    "From User" : "来自用户",
    "Since" : "自",
    "Until" : "直到",
    "No results found" : "未找到结果",
    "Load more results" : "加载更多结果",
    "Recent threads" : "最近的帖子",
    "Projects" : "项目",
    "No shared items" : "沒有已共享的项目",
    "Thread notifications" : "帖子通知",
    "Thread actions" : "帖子操作",
    "{actor}: {lastMessage}" : "{actor}：{lastMessage}",
    "Link to a conversation" : "链接到一个对话",
    "No open conversations found" : "没有找到公开对话",
    "Either there are no open conversations or you joined all of them." : "可能是没有公开对话，或是您已经加入了所有公开对话。",
    "Check spelling or use complete words." : "检查拼写或使用完整字词。",
    "Search conversations or users" : "搜索对话或用户",
    "Select conversation" : "选择对话",
    "Number length is not valid" : "号码长度不正确",
    "Region code is not valid" : "区号无效",
    "Number length is too short" : "号码太短",
    "Number length is too long" : "号码太长",
    "Number is not valid" : "号码无效",
    "Phone numbers" : "电话号码  ",
    "Display name: {name}" : "显示名称：{name}",
    "Edit display name" : "编辑显示名称",
    "Display name (required)" : "显示名称（必填）",
    "Save name" : "保存名称",
    "I picked message bubbles" : "我选了消息气泡",
    "I picked the list style" : "我已选择列表样式",
    "Error while setting personal setting" : "设置个人设置时出错",
    "Error while saving sounds setting" : "保存声音设置时出错",
    "Compact conversations list" : "紧凑的对话列表",
    "Chat appearance" : "聊天外观",
    "Messages list" : "消息列表",
    "Message bubbles" : "消息气泡",
    "Play sounds when participants join or leave a call" : "参与者加入或离开通话时播放声音",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "由于制造商的技术限制，目前无法在 iPhone 和 iPad 上使用",
    "Notification settings" : "通知设置",
    "Sounds for chat and call notifications" : "聊天和通话通知的声音",
    "Invalid language ({languageId})" : "无效语言（{languageId}）",
    "Default language" : "默认语言",
    "Default language ({languageName})" : "默认语言（{languageName}）",
    "Error when trying to load the available live translation languages" : "尝试加载可用的实时翻译语言时出错",
    "Error when trying to set live translation language" : "尝试设置实时翻译语言时出错",
    "Set language used to show the transcriptions" : "设置用于显示转录的语言",
    "Select location for attachments" : "选择附件的位置 ",
    "Error while setting attachment folder" : "设置附件文件夹时出错",
    "Error while setting read status privacy" : "设置读取状态隐私时发生错误 ",
    "Error while setting typing status privacy" : "设置打字状态隐私时发生错误",
    "Error while setting default media state" : "设置默认媒体状态时出错",
    "Turn camera and microphone off by default" : "默认关闭摄像头和麦克风",
    "Blur camera background by default" : "默认模糊相机背景",
    "Skip device preview before joining a call" : "加入通话前跳过设备预览",
    "Camera will be turned off when joining. Always shown if recording consent is required." : "加入后摄像头将自动关闭。如果需要录制同意，则会始终显示。",
    "Appearance & Sounds" : "外观和声音",
    "Privacy" : "隐私",
    "Send read receipts" : "发送已读回执",
    "When off, all read statuses will be hidden" : "关闭后，将隐藏所有阅读状态",
    "Share typing status" : "分享输入状态",
    "When off, all typing indicators will be hidden" : "关闭后，将隐藏所有输入指示器",
    "Attachments folder" : "附件文件夹",
    "Toggle full screen" : "切换全屏",
    "Return to Home screen" : "返回主屏幕",
    "Search" : "搜索",
    "Shortcuts while in a chat" : "聊天中的快捷键",
    "Focus the chat input" : "聚焦聊天输入",
    "Unfocus the chat input to use shortcuts" : "取消聊天输入框的焦点以使用快捷键",
    "Edit your last message" : "编辑您的最后一条消息",
    "Shortcuts while in a call" : "通话中的快捷键",
    "Camera on and off" : "摄像头开关",
    "Microphone on and off" : "麦克风开和关",
    "Raise or lower hand" : "举起手或放下手",
    "Push to talk or push to mute" : "按下讲话或按下静音",
    "Zoom-in / zoom-out a screen share" : "放大/缩小屏幕共享",
    "Mouse wheel" : "鼠标滚轮",
    "Start call silently" : "安静地开始通话",
    "Start call" : "开始通话",
    "End call" : "结束通话",
    "The server was updated, you cannot start or join a call." : "服务器已更新，您无法开始或加入通话。",
    "This call has just ended" : "此通话刚刚结束",
    "You will be able to join the call only after a moderator starts it." : "您只有在主持人开始一个通话之后才能加入通话。",
    "End call for everyone" : "为所有人结束通话",
    "Starting the recording" : "开始录制",
    "Recording" : "录音",
    "The call has been running for one hour." : "通话已持续一小时",
    "Cancel recording start" : "取消录制开始",
    "Stop recording" : "停止录制",
    "Send a reaction" : "发送回应",
    "React with {reaction}" : "使用{reaction}回应",
    "All tasks done!" : "所有任务完成！",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done}/%n 任务"],
    "Add participants to this call" : "将参与者添加到此通话",
    "_%n participant in call_::_%n participants in call_" : ["通话中有 %n 位参与者"],
    "Scheduled messages" : "已安排的消息",
    "You are not allowed to enable screensharing" : "你不被允许启用屏幕分享",
    "No screensharing" : "无屏幕分享",
    "Screensharing options" : "屏幕共享选项",
    "Enable screensharing" : "启用屏幕共享",
    "Bad sent video and screen quality." : "发送的视频和屏幕质量不好",
    "Bad sent screen quality." : "发送的屏幕质量不好",
    "Bad sent video quality." : "发送的视频质量不好",
    "Bad sent audio, video and screen quality." : "发送的音频、视频和屏幕质量不好。 ",
    "Bad sent audio and screen quality." : "发送的音频和屏幕质量不佳",
    "Bad sent audio and video quality." : "发送的音频和视频质量不佳",
    "Bad sent audio quality." : "发送的音频质量不好",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "您的网络连接或计算机繁忙，其他参与者可能无法看到您的屏幕。为了改善这种情况，尝试在进行屏幕共享时禁用背景模糊或您的视频。",
    "Disable background blur" : "禁用背景模糊",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "您的网络连接或计算机繁忙，其他参与者可能无法看到您的屏幕。为了改善这种情况，尝试在进行屏幕共享时禁用视频。",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "你的互联网连接或计算机繁忙，其他参与者可能无法看到你的屏幕。",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "你的互联网连接或计算机繁忙，其他参与者可能无法看到你。",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "您的网络连接或计算机繁忙，其他参与者可能无法理解和看到您。为了改善这种情况，尝试在进行屏幕共享时禁用背景模糊或您的视频。",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "你的互联网连接或计算机繁忙，其他参与者可能无法理解和看到你。为了改善这种情况，尝试在做屏幕分享时禁用你的视频。",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "您的网络连接或计算机正忙，其他参与者可能无法理解您的意思和看到您的屏幕。为了改善这种情况，可以试着禁用屏幕共享。",
    "Disable screenshare" : "禁用屏幕共享",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "您的网络连接或计算机繁忙，其他参与者可能无法理解和看到您。为了改善这种情况，尝试禁用背景模糊或您的视频。",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "你的互联网连接或计算机繁忙，其他参与者可能无法理解和看到你。为了改善这种情况，请禁用你的视频。",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "你的网络连接或计算机处于繁忙状态，其他与会者可能无法理解你的意思。",
    "Screen sharing is not supported by your browser." : "您的浏览器不支持屏幕共享。",
    "Screen sharing requires the page to be loaded through HTTPS." : "屏幕共享需要页面通过 HTTPS 加载。",
    "Screensharing requires the page to be loaded through HTTPS." : "屏幕共享需要页面通过 HTTPS 加载。",
    "An error occurred while starting screensharing." : "开始屏幕共享时发生错误。",
    "Select virtual background" : "选择虚拟背景",
    "Show your screen" : "显示您的屏幕",
    "Stop screensharing" : "停止屏幕共享",
    "Mute others" : "降低其他人的声音",
    "Start recording" : "开始录制",
    "Set up breakout rooms" : "设置分组讨论室",
    "Download attendance list" : "下载出席名单",
    "Open Calendar" : "打开日历",
    "Remove participant {name}" : "移除参与者{name}",
    "Would you like to delete this conversation?" : "是否删除此对话？",
    "_This conversation will be automatically deleted for everyone after %n day of inactivity._::_This conversation will be automatically deleted for everyone after %n days of inactivity._" : ["此对话将在 %n 天不活动后自动对所有人删除。"],
    "Are you sure you want to delete this conversation?" : "是否确定要删除此对话？",
    "Delete now" : "立即删除",
    "Keep" : "保留",
    "Open dialpad" : "打开拨号面板",
    "Select a region" : "选择国家/地区",
    "Local time: {time}" : "本地时间：{time}",
    "Scheduled {datetime}" : "预定于 {datetime}",
    "Scheduled for {datetime}" : "预定于 {datetime}",
    "Search …" : "搜索...",
    "Message without mention" : "没有提及的消息",
    "Mention myself" : "提到我自己",
    "Mention everyone" : "提及所有人",
    "Select a conversation" : "选择对话",
    "Select a mode" : "选择模式",
    "You do not have permissions to access this conversation." : "您没有访问此对话的权限。",
    "Join a different conversation or start a new one." : "加入不同的对话或开始新对话。",
    "The conversation does not exist" : "该对话不存在",
    "Join a conversation or start a new one!" : "加入对话或开始新的对话！",
    "Duplicate session" : "重复对话",
    "This conversation was opened in another tab. The current server version does not support opening a conversation in multiple tabs." : "此对话已在其他标签页中打开。当前服务器版本不支持在多个标签页中打开对话。",
    "Creating and joining a conversation with \"{userid}\"" : "使用“{userid}”创建和加入对话",
    "Join a conversation or start a new one" : "加入一个对话或开始新对话",
    "Error while joining the conversation" : "加入对话时出错",
    "Another user" : "其他用户",
    "Hey! Are you using the list style or message bubbles?" : "嘿！您是使用列表样式还是消息气泡？",
    "Nextcloud URL" : "Nextcloud URL ",
    "Nextcloud user" : "Nextcloud 用户",
    "User password" : "使用密码",
    "Talk conversation" : "对话",
    "Skip TLS verification" : "跳过 TLS 验证",
    "Matrix server URL" : "Matrix 服务器 URL",
    "User" : "用户",
    "Matrix channel" : "Matrix 频道",
    "Mattermost server URL" : "Mattermost 服务器 URL",
    "Mattermost user" : "Mattermost 用户",
    "Team name" : "团队名称",
    "Channel name" : "频道名称",
    "Rocket.Chat server URL" : "Rocket.Chat 服务器 URL",
    "User name or email address" : "用户名或电子邮件地址 ",
    "Rocket.Chat channel" : "Rocket.Chat 频道",
    "Zulip server URL" : "Zulip 服务器 URL",
    "Bot user name" : "机器人用户名",
    "Bot API key" : "机器人 API 密钥",
    "Zulip channel" : "Zulip 频道",
    "API token" : "API 令牌",
    "Slack channel" : "Slack 频道",
    "Server ID or name" : "服务器 ID 或名称",
    "Channel ID (prefixed with \"ID:\") or name" : "频道 ID（前缀为“ID:”）或名称",
    "Channel" : "频道",
    "Login" : "登录",
    "Chat ID" : "聊天 ID",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC 服务器 URL ( 如：chat.freenode.net:6667 )",
    "Nickname" : "昵称",
    "Connection password" : "连接密码",
    "IRC channel" : "IRC 频道",
    "Channel password" : "频道密码",
    "NickServ nickname" : "NickServ 昵称",
    "NickServ password" : "NickServ 密码",
    "Use TLS" : "使用 TLS",
    "Use SASL" : "使用 SASL",
    "Tenant ID" : "租户 ID",
    "Client ID" : "客户端ID",
    "Team ID" : "团队 ID",
    "Thread ID" : "帖子 ID",
    "XMPP/Jabber server URL" : "XMPP/Jabber 服务器 URL",
    "MUC server URL" : "MUC 服务器 URL",
    "Jabber ID" : "Jabber ID ",
    "Pinned messages" : "已置顶的消息",
    "Media" : "媒体文件",
    "Polls" : "投票",
    "Deck cards" : "看板卡片",
    "Voice messages" : "语音消息",
    "Locations" : "地点",
    "Call recordings" : "通话录制",
    "Audio" : "音频",
    "Show all pinned messages" : "显示所有已置顶的消息",
    "Show all media" : "显示所有媒体",
    "Show all files" : "显示所有文件",
    "Show all polls" : "显示所有投票",
    "Show all deck cards" : "显示所有看板卡片",
    "Show all voice messages" : "显示所有语音消息",
    "Show all locations" : "显示所有位置",
    "Show all call recordings" : "显示所有通话录制",
    "Show all audio" : "显示所有音频",
    "Show all other" : "显示所有其他",
    "Follow conversation settings" : "遵循对话设置",
    "Group" : "群组",
    "Team" : "团队",
    "You reconnected to the call" : "你重新连接到通话",
    "{actor} reconnected to the call" : "{actor} 重新连接到通话",
    "You added {user0} and {user1}" : "你添加了 {user0} 和 {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["你添加了 {user0} 、 {user1} 及另外%n个参与者"],
    "An administrator added you and {user0}" : "管理员已添加你和 {user0}",
    "{actor} added you and {user0}" : "{actor} 添加了你和 {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["管理员已添加你、 {user0} 及另外%n个参与者"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} 添加了你、 {user0} 及另外%n个参与者"],
    "An administrator added {user0} and {user1}" : "管理员已添加 {user0} 和 {user1}",
    "{actor} added {user0} and {user1}" : "{actor} 添加了 {user0} 和 {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["管理员已添加 {user0} 、 {user1} 及另外%n个参与者"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} 添加了 {user0} 、 {user1} 及另外%n个参与者"],
    "You removed {user0} and {user1}" : "您移除了 {user0} 和 {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["您移除了 {user0}、{user1} 和另外 %n 位参与者"],
    "An administrator removed you and {user0}" : "管理员移除了您和 {user0}",
    "{actor} removed you and {user0}" : "{actor} 移除了您和 {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["管理员移除了您、{user0} 和另外 %n 位参与者"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} 移除了您、{user0} 和另外 %n 位参与者"],
    "An administrator removed {user0} and {user1}" : "管理员移除了 {user0} 和 {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} 移除了 {user0} 和 {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["管理员移除了 {user0}、{user1} 和另外 %n 位参与者"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} 移除了 {user0}、{user1} 和另外 %n 位参与者"],
    "You and {user0} joined the call" : "您和 {user0} 加入了通话",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["您、{user0} 以及另外 %n 位参与者加入了通话"],
    "{user0} and {user1} joined the call" : "{user0} 和 {user1} 加入了通话",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}、{user1} 以及另外 %n 位参与者加入了通话"],
    "You and {user0} left the call" : "您和 {user0} 离开了通话",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["您、{user0} 以及另外 %n 位参与者离开了通话"],
    "{user0} and {user1} left the call" : "{user0} 和 {user1} 离开了通话",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}、{user1} 以及另外 %n 位参与者离开了通话"],
    "You promoted {user0} and {user1} to moderators" : "您将 {user0} 和 {user1} 设为了主持人",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["您将 {user0}、{user1} 以及另外 %n 位参与者设为了主持人"],
    "An administrator promoted you and {user0} to moderators" : "管理员将您和 {user0} 设为了主持人",
    "{actor} promoted you and {user0} to moderators" : "{actor} 将您和 {user0} 设为了主持人",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["管理员将您、{user0} 以及另外 %n 位参与者设为了主持人"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} 将您、{user0} 以及另外 %n 位参与者设为了主持人"],
    "An administrator promoted {user0} and {user1} to moderators" : "管理员将 {user0} 和 {user1} 设为了主持人",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} 将 {user0} 和 {user1} 设为了主持人",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["管理员将 {user0}、{user1} 以及另外 %n 位参与者设为了主持人"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} 将 {user0}、{user1} 以及另外 %n 位参与者设为了主持人"],
    "You demoted {user0} and {user1} from moderators" : "您取消了 {user0} 和 {user1} 的主持人身份",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["您取消了 {user0}、{user1} 及另外 %n 位参与者的主持人身份"],
    "An administrator demoted you and {user0} from moderators" : "管理员取消了您和 {user0} 的主持人身份",
    "{actor} demoted you and {user0} from moderators" : "{actor} 取消了您和 {user0} 的主持人身份",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["管理员取消了您、{user0} 以及另外 %n 位参与者的主持人身份"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} 取消了您、{user0} 以及另外 %n 位参与者的主持人身份"],
    "An administrator demoted {user0} and {user1} from moderators" : "管理员取消了 {user0} 和 {user1} 的主持人身份",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} 取消了 {user0} 和 {user1} 的主持人身份",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["管理员取消了 {user0}、{user1} 以及另外 %n 位参与者的主持人身份"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} 取消了 {user0}、{user1} 以及另外 %n 位参与者的主持人身份"],
    "You:" : "您：",
    "You: {lastMessage}" : "您：{lastMessage}",
    "{actor}:" : "{actor}：",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}，{absoluteDate}",
    "The server was updated." : "服务器已更新。",
    "(edited by you)" : "（由您编辑）",
    "(edited by a deleted user)" : "（由已删除的用户编辑）",
    "(edited by {moderator})" : "（由 {moderator} 编辑）",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "您正在尝试加入对话，但同时在另一个窗口或设备中有活动会话。Nextcloud通话应用目前不支持这么做。您想做什么？",
    "Leave this page" : "离开此页面",
    "Join here" : "点此加入",
    "Deck card has been posted to {conversation}" : "看板卡片已发送至 {conversation}",
    "An error occurred while posting deck card to conversation" : "将看板卡片发布到对话时发生错误",
    "Post to a conversation" : "发布到一个对话中",
    "Post to conversation" : "发布到对话中",
    "The recording failed. Please contact your administrator." : "录制失败。请联系您的管理员。",
    "Location has been posted to {conversation}" : "位置已发布到 {conversation}",
    "An error occurred while posting location to conversation" : "将位置发布到对话时发生错误",
    "Share to a conversation" : "分享到一个对话",
    "Share to conversation" : "分享到对话",
    "In conversation" : "对话中",
    "Search in conversation: {conversation}" : "在对话中搜索：{conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "由于暴力保护，您的请求目前受到限制",
    "Error while clearing conversation history" : "清除对话历史时出错",
    "Error occurred while allowing guests" : "允许访客时发生错误",
    "Error occurred while disallowing guests" : "禁止访客时发生错误",
    "Error occurred when restricting the conversation to moderator" : "将对话限制为主持人时发生错误",
    "Error occurred when opening the conversation to everyone" : "向所有人开放对话时发生错误",
    "Conversation password has been saved" : "对话密码已保存",
    "Conversation password has been removed" : "对话密码已被删除 ",
    "Error occurred while saving conversation password" : "保存对话密码时发生错误 ",
    "Call recording is starting." : "通话录制启动中。",
    "Call recording stopped while starting." : "通话录制启动时停止。",
    "Call recording stopped. You will be notified once the recording is available." : "通话录制已停止。您会在录制可用时收到通知。",
    "Conversation picture set" : "对话图片已设定",
    "Conversation picture deleted" : "对话图片已删除",
    "Could not delete the conversation picture" : "无法删除对话图片",
    "Could not remove the automatic expiration" : "无法移除自动过期",
    "Could not post message: {errorMessage}" : "无法发布消息: {errorMessage}",
    "Participant is banned successfully" : "成功封禁了参与者",
    "Error while banning the participant" : "封禁参与者时出错",
    "An error occurred while fetching the participants" : "获取参与者时出错",
    "Could not send invitation to {actorId}" : "无法发送邀请到 {actorId}",
    "Invitations sent" : "邀请已发送",
    "Error occurred when sending invitations" : "发送邀请时发生错误 ",
    "Failed to join the conversation." : "无法加入对话。",
    "An error occurred while creating breakout rooms" : "创建分组讨论室时发生了错误",
    "An error occurred while re-ordering the attendees" : "重新排序参加者时出错",
    "An error occurred while deleting breakout rooms" : "删除分组讨论室时发生错误",
    "An error occurred while starting breakout rooms" : "开始分组讨论室时发生错误",
    "An error occurred while stopping breakout rooms" : "停止分组讨论室时发生错误",
    "An error occurred while sending a message to the breakout rooms" : "向分组讨论室发送消息时发生错误",
    "An error occurred while requesting assistance" : "请求协助时发生错误·",
    "An error occurred while resetting the request for assistance" : "重置协助请求时发生错误",
    "An error occurred while joining breakout room" : "加入分组讨论室时发生错误",
    "Failed to rename the thread" : "无法重命名帖子",
    "Error fetching upcoming events" : "获取预定的活动时出错",
    "Error fetching upcoming reminders" : "获取预定的提醒时出错",
    "An error occurred while accepting an invitation" : "接受邀请时出错",
    "An error occurred while rejecting an invitation" : "拒绝邀请时出错",
    "{guest} (guest)" : "{guest}（访客）",
    "Poll draft has been saved" : "已保存投票草稿",
    "An error occurred while saving the draft" : "保存草稿时出错",
    "An error occurred while submitting your vote" : "提交您的投票时发生错误",
    "An error occurred while ending the poll" : "结束投票时发生错误",
    "An error occurred while deleting the poll draft" : "删除投票草稿时出错",
    "Poll \"{name}\" was created by {user}. Click to vote" : "{user} 创建了投票“{name}”，点击投票",
    "Failed to add reaction" : "无法添加回应",
    "Failed to remove reaction" : "无法移除回应",
    "The server is in maintenance mode." : "服务器处于维护模式。",
    "Federated server was updated." : "联合服务器已更新。",
    "Error while uploading file \"{fileName}\"" : "上传文件 \"{fileName}\" 时出错",
    "Not enough free space to upload file \"{fileName}\"" : "没有足够空间来上传文件 \"{fileName}\"",
    "You are not allowed to share files" : "您不被允许分享文件",
    "Error while sharing file" : "共享文件时出错",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Nextcloud通话应用并不完全支持你使用的浏览器。请使用最新版本的 Mozilla Firefox、Microsoft Edge、Google Chrome、Opera 或 Apple Safari 浏览器。",
    "_In %n hour_::_In %n hours_" : ["%n 小时内"],
    "_%n minute _::_%n minutes_" : ["%n 分钟"],
    "In {hours} and {minutes}" : "{hours} {minutes} 内",
    "_In %n minute_::_In %n minutes_" : ["%n 分钟内"],
    "Later today – {timeLocale}" : "今日稍晚 – {timeLocale}",
    "Set time for later today" : "设定今天晚些时候的时间",
    "Tomorrow – {timeLocale}" : "明天 – {timeLocale}",
    "Set time for tomorrow" : "设定明天的时间",
    "This weekend – {timeLocale}" : "本周末 – {timeLocale}",
    "Set time for this weekend" : "设定本周末的时间",
    "Next week – {timeLocale}" : "下周 – {timeLocale}",
    "Set time for next week" : "设定下周的时间",
    "Message link copied to clipboard" : "消息链接已复制到剪贴板",
    "Conversation link copied to clipboard" : "对话链接已复制到剪贴板。",
    "The link could not be copied" : "无法复制链接。",
    "Error while parsing a PROPFIND error" : "解析 PROPFIND 错误时出错",
    "Sending signaling message has failed" : "发送信令消息失败",
    "Lost connection to signaling server. Trying to reconnect." : "与信令服务器的连接中断，正在尝试重新连接。",
    "Lost connection to signaling server." : "与信令服务器连接中断。",
    "Connecting is taking longer than expected …" : "连接时间比预期长…",
    "Failed to connect. Retrying …" : "无法连接，正在重试…",
    "Failed to connect. The signaling server may be set up incorrectly" : "无法连接，信令服务器可能设置不正确",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "配置的信令服务器需要更新才能与此版本的 Talk 兼容，请联系您的管理员。",
    "Please restart the app." : "请重启应用。",
    "Please reload the page." : "请重新加载页面。",
    "Please try to restart the app." : "请尝试重启应用。",
    "Please try to reload the page." : "请尝试重新加载页面。",
    "Do not disturb" : "勿扰",
    "Away" : "离开",
    "Microphone {number}" : "第{number}号麦克风",
    "Camera {number}" : "第{number}号摄像头",
    "Speaker {number}" : "第{number}号扬声器",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "您似乎是在静音状态下讲话，请将您自己的静音取消使其他人能听到",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "无法与至少一个参与者建立连接。你的场景可能需要一个 TURN 服务器。请请求你的管理员按照 {linkstart}这个文档{linkend} 来设置一个。",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "耗时超出预期。媒体权限是否已被授予（或被拒绝）？如果已被授予，请重启您的浏览器，因为音视频当前无法工作",
    "Access to microphone & camera is only possible with HTTPS" : "仅使用 HTTPS 访问麦克风和摄像头",
    "Please move your setup to HTTPS" : "请将您的环境移至HTTPS",
    "Access to microphone & camera was denied" : "访问麦克风和摄像头被拒绝",
    "WebRTC is not supported in your browser" : "您的浏览器不支持 WebRTC",
    "Please use a different browser like Firefox or Chrome" : "请使用 Firefox 或 Chrome 等其他浏览器",
    "Error while accessing microphone & camera" : "访问麦克风和摄像头时出错",
    "%s Talk on your mobile devices" : "用于移动设备的%s通话应用",
    "Join conversations at any time, anywhere, on any device." : "随时随地在任何设备上加入对话。",
    "Android app" : "Android 应用",
    "iOS app" : "iOS 应用",
    "__language_name__" : "简体中文",
    "Webhook Demo" : "Webhook 演示",
    "Call summary (%s)" : "通话摘要 (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "通话摘要机器人会在通话结束后发布一条概述信息，列出所有与会者并概述各项任务",
    "Tasks" : "任务",
    "Notes" : "附注",
    "Reports" : "报告",
    "Decisions" : "决定",
    "Agenda" : "日程",
    "Call summary" : "通话摘要",
    "Call summary - {title}" : "通话摘要 - {title}",
    "Talk conversation for event" : "活动的 Talk 对话",
    "Client Push is installed, this improves the performance of desktop clients." : "已安装客户端推送，这提高了桌面客户端的性能。",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "未安装 {notify_push}，这可能会导致使用桌面客户端时出现性能问题。",
    "Next meeting" : "下次会议",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "从日历中安排会议。需要将 Talk 对话设置为位置才能在此处显示",
    "Join conversations from remote Nextcloud servers" : "从远程 Nextcloud 服务器加入对话",
    "Your default media state has been saved" : "已保存您的默认媒体状态",
    "Set reminder for later today" : "今日稍晚提醒",
    "Set reminder for tomorrow" : "明天提醒",
    "Set reminder for this weekend" : "本周末提醒",
    "Set reminder for next week" : "下周提醒",
    "Generate summary" : "生成摘要",
    "Open poll • You voted already" : "公开投票 · 您已投票",
    "Open poll • Click to vote" : "公开投票 · 点击投票",
    "Poll • Ended" : "投票 · 已结束",
    "Talk recording from {time} ({conversation})" : "{time}于({conversation})对话中的录制 ",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["投票結果 • %n票"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["公开投票 • %n票"],
    "Submit vote" : "提交投票",
    "Your privacy setting has been saved" : "你的隐私设置已保存",
    "Your personal setting has been saved" : "已保存您的个人设置",
    "Failed to save sounds setting" : "保存声音设置失败",
    "Sounds setting saved" : "声音设置已保存",
    "Always shown if recording consent is required" : "如果需要录制同意，则始终显示",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Talk 已更新，您无法开始或加入通话。",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "你在另一个窗口或设备上加入了对话。Nextcloud通话应用目前不支持这么做，所以这个会话被关闭了。",
    "Nextcloud Talk was updated." : "Nextcloud Talk 已更新。",
    "Nextcloud is in maintenance mode." : "Nextcloud 处于维护模式。",
    "Nextcloud Talk Federation was updated." : "Nextcloud Talk Federation 已更新。",
    "Enable live translation" : "启用实时翻译",
    "I picked list style" : "我择了列表样式",
    "Hey! Are you using Talk in list style or with message bubbles?" : "嘿！您是使用列表样式还是有消息气泡的 Talk？"
},
"nplurals=1; plural=0;");
